operations = {
    "adFreeArticleDomains": {
        "queryId": "zwTrX9CtnMvWlBXjsx95RQ",
        "variables": {},
        "features": {}
    },
    "articleNudgeDomains": {
        "queryId": "88Bu08U2ddaVVjKmmXjVYg",
        "variables": {},
        "features": {}
    },
    "ArticleTimeline": {
        "queryId": "W1z1htHs9h4ru8SakhgqYw",
        "variables": {},
        "features": {
            "responsive_web_twitter_blue_verified_badge_is_enabled": True,
            "responsive_web_graphql_exclude_directive_enabled": True,
            "verified_phone_label_enabled": True,
            "responsive_web_graphql_timeline_navigation_enabled": True,
            "responsive_web_graphql_skip_user_profile_image_extensions_enabled": True,
            "tweetypie_unmention_optimization_enabled": True,
            "vibe_api_enabled": True,
            "responsive_web_edit_tweet_api_enabled": True,
            "graphql_is_translatable_rweb_tweet_is_translatable_enabled": True,
            "view_counts_everywhere_api_enabled": True,
            "longform_notetweets_consumption_enabled": True,
            "tweet_awards_web_tipping_enabled": True,
            "freedom_of_speech_not_reach_fetch_enabled": True,
            "standardized_nudges_misinfo": True,
            "tweet_with_visibility_results_prefer_gql_limited_actions_policy_enabled": True,
            "interactive_text_enabled": True,
            "responsive_web_text_conversations_enabled": True,
            "longform_notetweets_richtext_consumption_enabled": True,
            "responsive_web_enhance_cards_enabled": True
        }
    },
    "ArticleTweetsTimeline": {
        "queryId": "iVzorsgswtr8J7g6JJqTIQ",
        "variables": {},
        "features": {
            "responsive_web_twitter_blue_verified_badge_is_enabled": True,
            "responsive_web_graphql_exclude_directive_enabled": True,
            "verified_phone_label_enabled": True,
            "responsive_web_graphql_timeline_navigation_enabled": True,
            "responsive_web_graphql_skip_user_profile_image_extensions_enabled": True,
            "tweetypie_unmention_optimization_enabled": True,
            "vibe_api_enabled": True,
            "responsive_web_edit_tweet_api_enabled": True,
            "graphql_is_translatable_rweb_tweet_is_translatable_enabled": True,
            "view_counts_everywhere_api_enabled": True,
            "longform_notetweets_consumption_enabled": True,
            "tweet_awards_web_tipping_enabled": True,
            "freedom_of_speech_not_reach_fetch_enabled": True,
            "standardized_nudges_misinfo": True,
            "tweet_with_visibility_results_prefer_gql_limited_actions_policy_enabled": True,
            "interactive_text_enabled": True,
            "responsive_web_text_conversations_enabled": True,
            "longform_notetweets_richtext_consumption_enabled": True,
            "responsive_web_enhance_cards_enabled": True
        }
    },
    "AudioSpaceById": {
        "queryId": "LteLU4uHTpSNobexxKBO6g",
        "variables": {},
        "features": {
            "spaces_2022_h2_clipping": True,
            "spaces_2022_h2_spaces_communities": True,
            "responsive_web_twitter_blue_verified_badge_is_enabled": True,
            "responsive_web_graphql_exclude_directive_enabled": True,
            "verified_phone_label_enabled": True,
            "responsive_web_graphql_skip_user_profile_image_extensions_enabled": True,
            "tweetypie_unmention_optimization_enabled": True,
            "vibe_api_enabled": True,
            "responsive_web_edit_tweet_api_enabled": True,
            "graphql_is_translatable_rweb_tweet_is_translatable_enabled": True,
            "view_counts_everywhere_api_enabled": True,
            "longform_notetweets_consumption_enabled": True,
            "tweet_awards_web_tipping_enabled": True,
            "freedom_of_speech_not_reach_fetch_enabled": True,
            "standardized_nudges_misinfo": True,
            "tweet_with_visibility_results_prefer_gql_limited_actions_policy_enabled": True,
            "responsive_web_graphql_timeline_navigation_enabled": True,
            "interactive_text_enabled": True,
            "responsive_web_text_conversations_enabled": True,
            "longform_notetweets_richtext_consumption_enabled": True,
            "responsive_web_enhance_cards_enabled": True
        }
    },
    "AudioSpaceSearch": {
        "queryId": "NTq79TuSz6fHj8lQaferJw",
        "variables": {},
        "features": {}
    },
    "getAltTextPromptPreference": {
        "queryId": "PFIxTk8owMoZgiMccP0r4g",
        "variables": {},
        "features": {}
    },
    "updateAltTextPromptPreference": {
        "queryId": "aQKrduk_DA46XfOQDkcEng",
        "variables": {},
        "features": {}
    },
    "getCaptionsAlwaysDisplayPreference": {
        "queryId": "BwgMOGpOViDS0ri7VUgglg",
        "variables": {},
        "features": {}
    },
    "updateCaptionsAlwaysDisplayPreference": {
        "queryId": "uCUQhvZ5sJ9qHinRp6CFlQ",
        "variables": {},
        "features": {}
    },
    "AuthenticatedUserTFLists": {
        "queryId": "QjN8ZdavFDqxUjNn3r9cig",
        "variables": {},
        "features": {}
    },
    "BirdwatchAliasSelect": {
        "queryId": "3ss48WFwGokBH_gj8t_8aQ",
        "variables": {},
        "features": {}
    },
    "BirdwatchFetchContributorNotesSlice": {
        "queryId": "mIXxHndBm97VfcNYccuukw",
        "variables": {},
        "features": {
            "responsive_web_graphql_timeline_navigation_enabled": True,
            "tweetypie_unmention_optimization_enabled": True,
            "vibe_api_enabled": True,
            "responsive_web_edit_tweet_api_enabled": True,
            "graphql_is_translatable_rweb_tweet_is_translatable_enabled": True,
            "view_counts_everywhere_api_enabled": True,
            "longform_notetweets_consumption_enabled": True,
            "tweet_awards_web_tipping_enabled": True,
            "freedom_of_speech_not_reach_fetch_enabled": True,
            "standardized_nudges_misinfo": True,
            "tweet_with_visibility_results_prefer_gql_limited_actions_policy_enabled": True,
            "interactive_text_enabled": True,
            "responsive_web_text_conversations_enabled": True,
            "longform_notetweets_richtext_consumption_enabled": True,
            "responsive_web_twitter_blue_verified_badge_is_enabled": True,
            "responsive_web_graphql_exclude_directive_enabled": True,
            "verified_phone_label_enabled": True,
            "responsive_web_graphql_skip_user_profile_image_extensions_enabled": True,
            "responsive_web_enhance_cards_enabled": True
        }
    },
    "BirdwatchCreateAppeal": {
        "queryId": "TKdL0YFsX4DMOpMKeneLvA",
        "variables": {},
        "features": {}
    },
    "BirdwatchCreateNote": {
        "queryId": "0fOzFT_8za8AUyJv3pERkA",
        "variables": {},
        "features": {
            "responsive_web_graphql_timeline_navigation_enabled": True,
            "responsive_web_twitter_blue_verified_badge_is_enabled": True,
            "responsive_web_graphql_exclude_directive_enabled": True,
            "verified_phone_label_enabled": True,
            "responsive_web_graphql_skip_user_profile_image_extensions_enabled": True
        }
    },
    "BirdwatchCreateRating": {
        "queryId": "xWLuzZoATvfEIEGxnsLt7w",
        "variables": {},
        "features": {}
    },
    "BirdwatchDeleteNote": {
        "queryId": "IKS_qrShkDyor6Ri1ahd9g",
        "variables": {},
        "features": {}
    },
    "BirdwatchDeleteRating": {
        "queryId": "OpvCOyOoQClUND66zDzrnA",
        "variables": {},
        "features": {}
    },
    "BirdwatchEditNotificationSettings": {
        "queryId": "FLgLReVIssXjB_ui3wcrRQ",
        "variables": {},
        "features": {}
    },
    "BirdwatchFetchAliasSelfSelectOptions": {
        "queryId": "szoXMke8AZOErso908iglw",
        "variables": {},
        "features": {}
    },
    "BirdwatchFetchAliasSelfSelectStatus": {
        "queryId": "LUEdtkcpBlGktUtms4BvwA",
        "variables": {},
        "features": {}
    },
    "BirdwatchFetchAuthenticatedUserProfile": {
        "queryId": "pMbW6Y4LuS5MzlSOEqERJQ",
        "variables": {},
        "features": {}
    },
    "BirdwatchFetchBirdwatchProfile": {
        "queryId": "btgGtchypc3D491MJ7XXWA",
        "variables": {},
        "features": {}
    },
    "BirdwatchFetchGlobalTimeline": {
        "queryId": "SQfYgFHuQlKtVeLz1NkaqA",
        "variables": {},
        "features": {
            "responsive_web_twitter_blue_verified_badge_is_enabled": True,
            "responsive_web_graphql_exclude_directive_enabled": True,
            "verified_phone_label_enabled": True,
            "responsive_web_graphql_timeline_navigation_enabled": True,
            "responsive_web_graphql_skip_user_profile_image_extensions_enabled": True,
            "tweetypie_unmention_optimization_enabled": True,
            "vibe_api_enabled": True,
            "responsive_web_edit_tweet_api_enabled": True,
            "graphql_is_translatable_rweb_tweet_is_translatable_enabled": True,
            "view_counts_everywhere_api_enabled": True,
            "longform_notetweets_consumption_enabled": True,
            "tweet_awards_web_tipping_enabled": True,
            "freedom_of_speech_not_reach_fetch_enabled": True,
            "standardized_nudges_misinfo": True,
            "tweet_with_visibility_results_prefer_gql_limited_actions_policy_enabled": True,
            "interactive_text_enabled": True,
            "responsive_web_text_conversations_enabled": True,
            "longform_notetweets_richtext_consumption_enabled": True,
            "responsive_web_enhance_cards_enabled": True
        }
    },
    "BirdwatchFetchNotes": {
        "queryId": "-pJbOdvuR19SngusywIjRA",
        "variables": {},
        "features": {
            "responsive_web_graphql_timeline_navigation_enabled": True,
            "responsive_web_twitter_blue_verified_badge_is_enabled": True,
            "responsive_web_graphql_exclude_directive_enabled": True,
            "verified_phone_label_enabled": True,
            "responsive_web_graphql_skip_user_profile_image_extensions_enabled": True
        }
    },
    "BirdwatchFetchOneNote": {
        "queryId": "LT8P2AoBObbK2tQL75vwPA",
        "variables": {},
        "features": {
            "responsive_web_graphql_timeline_navigation_enabled": True,
            "responsive_web_twitter_blue_verified_badge_is_enabled": True,
            "responsive_web_graphql_exclude_directive_enabled": True,
            "verified_phone_label_enabled": True,
            "responsive_web_graphql_skip_user_profile_image_extensions_enabled": True
        }
    },
    "BirdwatchFetchPublicData": {
        "queryId": "9bDdJ6AL26RLkcUShEcF-A",
        "variables": {},
        "features": {}
    },
    "BirdwatchProfileAcknowledgeEarnOut": {
        "queryId": "cED9wJy8Nd1kZCCYuIq9zQ",
        "variables": {},
        "features": {}
    },
    "BizProfileFetchUser": {
        "queryId": "6OFpJ3TH3p8JpwOSgfgyhg",
        "variables": {},
        "features": {}
    },
    "BlockedAccountsAll": {
        "queryId": "HbDY9-1fVikEj9wOirxyxA",
        "variables": {},
        "features": {
            "responsive_web_twitter_blue_verified_badge_is_enabled": True,
            "responsive_web_graphql_exclude_directive_enabled": True,
            "verified_phone_label_enabled": True,
            "responsive_web_graphql_timeline_navigation_enabled": True,
            "responsive_web_graphql_skip_user_profile_image_extensions_enabled": True,
            "tweetypie_unmention_optimization_enabled": True,
            "vibe_api_enabled": True,
            "responsive_web_edit_tweet_api_enabled": True,
            "graphql_is_translatable_rweb_tweet_is_translatable_enabled": True,
            "view_counts_everywhere_api_enabled": True,
            "longform_notetweets_consumption_enabled": True,
            "tweet_awards_web_tipping_enabled": True,
            "freedom_of_speech_not_reach_fetch_enabled": True,
            "standardized_nudges_misinfo": True,
            "tweet_with_visibility_results_prefer_gql_limited_actions_policy_enabled": True,
            "interactive_text_enabled": True,
            "responsive_web_text_conversations_enabled": True,
            "longform_notetweets_richtext_consumption_enabled": True,
            "responsive_web_enhance_cards_enabled": True
        }
    },
    "BlockedAccountsAutoBlock": {
        "queryId": "T4QVCFXTSKXAX8wBkBK-ag",
        "variables": {},
        "features": {
            "responsive_web_twitter_blue_verified_badge_is_enabled": True,
            "responsive_web_graphql_exclude_directive_enabled": True,
            "verified_phone_label_enabled": True,
            "responsive_web_graphql_timeline_navigation_enabled": True,
            "responsive_web_graphql_skip_user_profile_image_extensions_enabled": True,
            "tweetypie_unmention_optimization_enabled": True,
            "vibe_api_enabled": True,
            "responsive_web_edit_tweet_api_enabled": True,
            "graphql_is_translatable_rweb_tweet_is_translatable_enabled": True,
            "view_counts_everywhere_api_enabled": True,
            "longform_notetweets_consumption_enabled": True,
            "tweet_awards_web_tipping_enabled": True,
            "freedom_of_speech_not_reach_fetch_enabled": True,
            "standardized_nudges_misinfo": True,
            "tweet_with_visibility_results_prefer_gql_limited_actions_policy_enabled": True,
            "interactive_text_enabled": True,
            "responsive_web_text_conversations_enabled": True,
            "longform_notetweets_richtext_consumption_enabled": True,
            "responsive_web_enhance_cards_enabled": True
        }
    },
    "BlockedAccountsImported": {
        "queryId": "BpHrU2AZLU-fgy0pqHWjng",
        "variables": {},
        "features": {
            "responsive_web_twitter_blue_verified_badge_is_enabled": True,
            "responsive_web_graphql_exclude_directive_enabled": True,
            "verified_phone_label_enabled": True,
            "responsive_web_graphql_timeline_navigation_enabled": True,
            "responsive_web_graphql_skip_user_profile_image_extensions_enabled": True,
            "tweetypie_unmention_optimization_enabled": True,
            "vibe_api_enabled": True,
            "responsive_web_edit_tweet_api_enabled": True,
            "graphql_is_translatable_rweb_tweet_is_translatable_enabled": True,
            "view_counts_everywhere_api_enabled": True,
            "longform_notetweets_consumption_enabled": True,
            "tweet_awards_web_tipping_enabled": True,
            "freedom_of_speech_not_reach_fetch_enabled": True,
            "standardized_nudges_misinfo": True,
            "tweet_with_visibility_results_prefer_gql_limited_actions_policy_enabled": True,
            "interactive_text_enabled": True,
            "responsive_web_text_conversations_enabled": True,
            "longform_notetweets_richtext_consumption_enabled": True,
            "responsive_web_enhance_cards_enabled": True
        }
    },
    "BookmarkFolderTimeline": {
        "queryId": "a2wY9S9Ez1VE6_2KVKAIDA",
        "variables": {},
        "features": {
            "responsive_web_twitter_blue_verified_badge_is_enabled": True,
            "responsive_web_graphql_exclude_directive_enabled": True,
            "verified_phone_label_enabled": True,
            "responsive_web_graphql_timeline_navigation_enabled": True,
            "responsive_web_graphql_skip_user_profile_image_extensions_enabled": True,
            "tweetypie_unmention_optimization_enabled": True,
            "vibe_api_enabled": True,
            "responsive_web_edit_tweet_api_enabled": True,
            "graphql_is_translatable_rweb_tweet_is_translatable_enabled": True,
            "view_counts_everywhere_api_enabled": True,
            "longform_notetweets_consumption_enabled": True,
            "tweet_awards_web_tipping_enabled": True,
            "freedom_of_speech_not_reach_fetch_enabled": True,
            "standardized_nudges_misinfo": True,
            "tweet_with_visibility_results_prefer_gql_limited_actions_policy_enabled": True,
            "interactive_text_enabled": True,
            "responsive_web_text_conversations_enabled": True,
            "longform_notetweets_richtext_consumption_enabled": True,
            "responsive_web_enhance_cards_enabled": True
        }
    },
    "BookmarkFoldersSlice": {
        "queryId": "i78YDd0Tza-dV4SYs58kRg",
        "variables": {},
        "features": {}
    },
    "bookmarkTweetToFolder": {
        "queryId": "4KHZvvNbHNf07bsgnL9gWA",
        "variables": {},
        "features": {}
    },
    "Bookmarks": {
        "queryId": "HnZOTwULzK8gojG2upOHOA",
        "variables": {},
        "features": {
            "graphql_timeline_v2_bookmark_timeline": True,
            "responsive_web_twitter_blue_verified_badge_is_enabled": True,
            "responsive_web_graphql_exclude_directive_enabled": True,
            "verified_phone_label_enabled": True,
            "responsive_web_graphql_timeline_navigation_enabled": True,
            "responsive_web_graphql_skip_user_profile_image_extensions_enabled": True,
            "tweetypie_unmention_optimization_enabled": True,
            "vibe_api_enabled": True,
            "responsive_web_edit_tweet_api_enabled": True,
            "graphql_is_translatable_rweb_tweet_is_translatable_enabled": True,
            "view_counts_everywhere_api_enabled": True,
            "longform_notetweets_consumption_enabled": True,
            "tweet_awards_web_tipping_enabled": True,
            "freedom_of_speech_not_reach_fetch_enabled": True,
            "standardized_nudges_misinfo": True,
            "tweet_with_visibility_results_prefer_gql_limited_actions_policy_enabled": True,
            "interactive_text_enabled": True,
            "responsive_web_text_conversations_enabled": True,
            "longform_notetweets_richtext_consumption_enabled": True,
            "responsive_web_enhance_cards_enabled": True
        }
    },
    "CardPreviewByTweetText": {
        "queryId": "mDT5pi--P4qMjgtOPDN1Fw",
        "variables": {},
        "features": {
            "responsive_web_enhance_cards_enabled": True,
            "responsive_web_twitter_blue_verified_badge_is_enabled": True,
            "responsive_web_graphql_exclude_directive_enabled": True,
            "verified_phone_label_enabled": True,
            "responsive_web_graphql_skip_user_profile_image_extensions_enabled": True,
            "responsive_web_graphql_timeline_navigation_enabled": True
        }
    },
    "CheckTweetForNudge": {
        "queryId": "C2dcvh7H69JALtomErxWlA",
        "variables": {},
        "features": {
            "standardized_nudges_toxicity": True
        }
    },
    "CombinedLists": {
        "queryId": "SUxXZi0bXEkOOyVNfy-PWw",
        "variables": {},
        "features": {
            "responsive_web_twitter_blue_verified_badge_is_enabled": True,
            "responsive_web_graphql_exclude_directive_enabled": True,
            "verified_phone_label_enabled": True,
            "responsive_web_graphql_timeline_navigation_enabled": True,
            "responsive_web_graphql_skip_user_profile_image_extensions_enabled": True,
            "tweetypie_unmention_optimization_enabled": True,
            "vibe_api_enabled": True,
            "responsive_web_edit_tweet_api_enabled": True,
            "graphql_is_translatable_rweb_tweet_is_translatable_enabled": True,
            "view_counts_everywhere_api_enabled": True,
            "longform_notetweets_consumption_enabled": True,
            "tweet_awards_web_tipping_enabled": True,
            "freedom_of_speech_not_reach_fetch_enabled": True,
            "standardized_nudges_misinfo": True,
            "tweet_with_visibility_results_prefer_gql_limited_actions_policy_enabled": True,
            "interactive_text_enabled": True,
            "responsive_web_text_conversations_enabled": True,
            "longform_notetweets_richtext_consumption_enabled": True,
            "responsive_web_enhance_cards_enabled": True
        }
    },
    "CommunitiesMainDiscoveryModule": {
        "queryId": "jNPyfv5EX_uQeaMonzsQjw",
        "variables": {},
        "features": {
            "responsive_web_twitter_blue_verified_badge_is_enabled": True,
            "responsive_web_graphql_exclude_directive_enabled": True,
            "verified_phone_label_enabled": True,
            "responsive_web_graphql_timeline_navigation_enabled": True,
            "responsive_web_graphql_skip_user_profile_image_extensions_enabled": True,
            "tweetypie_unmention_optimization_enabled": True,
            "vibe_api_enabled": True,
            "responsive_web_edit_tweet_api_enabled": True,
            "graphql_is_translatable_rweb_tweet_is_translatable_enabled": True,
            "view_counts_everywhere_api_enabled": True,
            "longform_notetweets_consumption_enabled": True,
            "tweet_awards_web_tipping_enabled": True,
            "freedom_of_speech_not_reach_fetch_enabled": True,
            "standardized_nudges_misinfo": True,
            "tweet_with_visibility_results_prefer_gql_limited_actions_policy_enabled": True,
            "interactive_text_enabled": True,
            "responsive_web_text_conversations_enabled": True,
            "longform_notetweets_richtext_consumption_enabled": True,
            "responsive_web_enhance_cards_enabled": True
        }
    },
    "CommunitiesMainPageTimeline": {
        "queryId": "9NSoMSUeACwllJ12VG4yJQ",
        "variables": {},
        "features": {
            "responsive_web_twitter_blue_verified_badge_is_enabled": True,
            "responsive_web_graphql_exclude_directive_enabled": True,
            "verified_phone_label_enabled": True,
            "responsive_web_graphql_timeline_navigation_enabled": True,
            "responsive_web_graphql_skip_user_profile_image_extensions_enabled": True,
            "tweetypie_unmention_optimization_enabled": True,
            "vibe_api_enabled": True,
            "responsive_web_edit_tweet_api_enabled": True,
            "graphql_is_translatable_rweb_tweet_is_translatable_enabled": True,
            "view_counts_everywhere_api_enabled": True,
            "longform_notetweets_consumption_enabled": True,
            "tweet_awards_web_tipping_enabled": True,
            "freedom_of_speech_not_reach_fetch_enabled": True,
            "standardized_nudges_misinfo": True,
            "tweet_with_visibility_results_prefer_gql_limited_actions_policy_enabled": True,
            "interactive_text_enabled": True,
            "responsive_web_text_conversations_enabled": True,
            "longform_notetweets_richtext_consumption_enabled": True,
            "responsive_web_enhance_cards_enabled": True
        }
    },
    "CommunitiesMembershipsSlice": {
        "queryId": "oGlWHAR0sUlzCexh6AuAiw",
        "variables": {},
        "features": {
            "responsive_web_twitter_blue_verified_badge_is_enabled": True,
            "responsive_web_graphql_exclude_directive_enabled": True,
            "verified_phone_label_enabled": True,
            "responsive_web_graphql_skip_user_profile_image_extensions_enabled": True,
            "responsive_web_graphql_timeline_navigation_enabled": True
        }
    },
    "CommunitiesMembershipsTimeline": {
        "queryId": "OOJY08fdmM1M37NUwYy58g",
        "variables": {},
        "features": {
            "responsive_web_twitter_blue_verified_badge_is_enabled": True,
            "responsive_web_graphql_exclude_directive_enabled": True,
            "verified_phone_label_enabled": True,
            "responsive_web_graphql_timeline_navigation_enabled": True,
            "responsive_web_graphql_skip_user_profile_image_extensions_enabled": True,
            "tweetypie_unmention_optimization_enabled": True,
            "vibe_api_enabled": True,
            "responsive_web_edit_tweet_api_enabled": True,
            "graphql_is_translatable_rweb_tweet_is_translatable_enabled": True,
            "view_counts_everywhere_api_enabled": True,
            "longform_notetweets_consumption_enabled": True,
            "tweet_awards_web_tipping_enabled": True,
            "freedom_of_speech_not_reach_fetch_enabled": True,
            "standardized_nudges_misinfo": True,
            "tweet_with_visibility_results_prefer_gql_limited_actions_policy_enabled": True,
            "interactive_text_enabled": True,
            "responsive_web_text_conversations_enabled": True,
            "longform_notetweets_richtext_consumption_enabled": True,
            "responsive_web_enhance_cards_enabled": True
        }
    },
    "CommunityAboutTimeline": {
        "queryId": "BMongINo1Q1WVusV2WfOFA",
        "variables": {},
        "features": {
            "responsive_web_twitter_blue_verified_badge_is_enabled": True,
            "responsive_web_graphql_exclude_directive_enabled": True,
            "verified_phone_label_enabled": True,
            "responsive_web_graphql_timeline_navigation_enabled": True,
            "responsive_web_graphql_skip_user_profile_image_extensions_enabled": True,
            "tweetypie_unmention_optimization_enabled": True,
            "vibe_api_enabled": True,
            "responsive_web_edit_tweet_api_enabled": True,
            "graphql_is_translatable_rweb_tweet_is_translatable_enabled": True,
            "view_counts_everywhere_api_enabled": True,
            "longform_notetweets_consumption_enabled": True,
            "tweet_awards_web_tipping_enabled": True,
            "freedom_of_speech_not_reach_fetch_enabled": True,
            "standardized_nudges_misinfo": True,
            "tweet_with_visibility_results_prefer_gql_limited_actions_policy_enabled": True,
            "interactive_text_enabled": True,
            "responsive_web_text_conversations_enabled": True,
            "longform_notetweets_richtext_consumption_enabled": True,
            "responsive_web_enhance_cards_enabled": True
        }
    },
    "CreateCommunity": {
        "queryId": "FRwKGFOc5TketEaA8am7pA",
        "variables": {},
        "features": {
            "responsive_web_twitter_blue_verified_badge_is_enabled": True,
            "responsive_web_graphql_exclude_directive_enabled": True,
            "verified_phone_label_enabled": True,
            "responsive_web_graphql_skip_user_profile_image_extensions_enabled": True,
            "responsive_web_graphql_timeline_navigation_enabled": True
        }
    },
    "CommunityCreateRule": {
        "queryId": "oP6AkKK7cj6f2DcKNxoRlQ",
        "variables": {},
        "features": {
            "responsive_web_twitter_blue_verified_badge_is_enabled": True,
            "responsive_web_graphql_exclude_directive_enabled": True,
            "verified_phone_label_enabled": True,
            "responsive_web_graphql_skip_user_profile_image_extensions_enabled": True,
            "responsive_web_graphql_timeline_navigation_enabled": True
        }
    },
    "CommunityDiscoveryTimeline": {
        "queryId": "dnJxTUqEYiBYmHnEeiQgYQ",
        "variables": {},
        "features": {
            "responsive_web_twitter_blue_verified_badge_is_enabled": True,
            "responsive_web_graphql_exclude_directive_enabled": True,
            "verified_phone_label_enabled": True,
            "responsive_web_graphql_timeline_navigation_enabled": True,
            "responsive_web_graphql_skip_user_profile_image_extensions_enabled": True,
            "tweetypie_unmention_optimization_enabled": True,
            "vibe_api_enabled": True,
            "responsive_web_edit_tweet_api_enabled": True,
            "graphql_is_translatable_rweb_tweet_is_translatable_enabled": True,
            "view_counts_everywhere_api_enabled": True,
            "longform_notetweets_consumption_enabled": True,
            "tweet_awards_web_tipping_enabled": True,
            "freedom_of_speech_not_reach_fetch_enabled": True,
            "standardized_nudges_misinfo": True,
            "tweet_with_visibility_results_prefer_gql_limited_actions_policy_enabled": True,
            "interactive_text_enabled": True,
            "responsive_web_text_conversations_enabled": True,
            "longform_notetweets_richtext_consumption_enabled": True,
            "responsive_web_enhance_cards_enabled": True
        }
    },
    "CommunityEditBannerMedia": {
        "queryId": "PZNCgKSCnONh2jsgN-k0_A",
        "variables": {},
        "features": {
            "responsive_web_twitter_blue_verified_badge_is_enabled": True,
            "responsive_web_graphql_exclude_directive_enabled": True,
            "verified_phone_label_enabled": True,
            "responsive_web_graphql_skip_user_profile_image_extensions_enabled": True,
            "responsive_web_graphql_timeline_navigation_enabled": True
        }
    },
    "CommunityEditName": {
        "queryId": "kn6YYszpnCudapuWHGxnkg",
        "variables": {},
        "features": {
            "responsive_web_twitter_blue_verified_badge_is_enabled": True,
            "responsive_web_graphql_exclude_directive_enabled": True,
            "verified_phone_label_enabled": True,
            "responsive_web_graphql_skip_user_profile_image_extensions_enabled": True,
            "responsive_web_graphql_timeline_navigation_enabled": True
        }
    },
    "CommunityEditPurpose": {
        "queryId": "uuOoZHAHPWv1_V8k998eZg",
        "variables": {},
        "features": {
            "responsive_web_twitter_blue_verified_badge_is_enabled": True,
            "responsive_web_graphql_exclude_directive_enabled": True,
            "verified_phone_label_enabled": True,
            "responsive_web_graphql_skip_user_profile_image_extensions_enabled": True,
            "responsive_web_graphql_timeline_navigation_enabled": True
        }
    },
    "CommunityEditRule": {
        "queryId": "5V5kR0PJpOSlo1IZHHC4CQ",
        "variables": {},
        "features": {
            "responsive_web_twitter_blue_verified_badge_is_enabled": True,
            "responsive_web_graphql_exclude_directive_enabled": True,
            "verified_phone_label_enabled": True,
            "responsive_web_graphql_skip_user_profile_image_extensions_enabled": True,
            "responsive_web_graphql_timeline_navigation_enabled": True
        }
    },
    "CommunityEditTheme": {
        "queryId": "tFy6WYNhA-KWvlF29JN3ZA",
        "variables": {},
        "features": {
            "responsive_web_twitter_blue_verified_badge_is_enabled": True,
            "responsive_web_graphql_exclude_directive_enabled": True,
            "verified_phone_label_enabled": True,
            "responsive_web_graphql_skip_user_profile_image_extensions_enabled": True,
            "responsive_web_graphql_timeline_navigation_enabled": True
        }
    },
    "CommunityByRestId": {
        "queryId": "RTazUCzfsW4JAAho85cyFA",
        "variables": {},
        "features": {
            "responsive_web_twitter_blue_verified_badge_is_enabled": True,
            "responsive_web_graphql_exclude_directive_enabled": True,
            "verified_phone_label_enabled": True,
            "responsive_web_graphql_skip_user_profile_image_extensions_enabled": True,
            "responsive_web_graphql_timeline_navigation_enabled": True
        }
    },
    "CommunityHashtagsTimeline": {
        "queryId": "fACvkGDZbhOlpmpgsxnLfA",
        "variables": {},
        "features": {
            "responsive_web_twitter_blue_verified_badge_is_enabled": True,
            "responsive_web_graphql_exclude_directive_enabled": True,
            "verified_phone_label_enabled": True,
            "responsive_web_graphql_timeline_navigation_enabled": True,
            "responsive_web_graphql_skip_user_profile_image_extensions_enabled": True,
            "tweetypie_unmention_optimization_enabled": True,
            "vibe_api_enabled": True,
            "responsive_web_edit_tweet_api_enabled": True,
            "graphql_is_translatable_rweb_tweet_is_translatable_enabled": True,
            "view_counts_everywhere_api_enabled": True,
            "longform_notetweets_consumption_enabled": True,
            "tweet_awards_web_tipping_enabled": True,
            "freedom_of_speech_not_reach_fetch_enabled": True,
            "standardized_nudges_misinfo": True,
            "tweet_with_visibility_results_prefer_gql_limited_actions_policy_enabled": True,
            "interactive_text_enabled": True,
            "responsive_web_text_conversations_enabled": True,
            "longform_notetweets_richtext_consumption_enabled": True,
            "responsive_web_enhance_cards_enabled": True
        }
    },
    "JoinCommunity": {
        "queryId": "n7b-wm-4reLhE-pA0W_PMQ",
        "variables": {},
        "features": {
            "responsive_web_twitter_blue_verified_badge_is_enabled": True,
            "responsive_web_graphql_exclude_directive_enabled": True,
            "verified_phone_label_enabled": True,
            "responsive_web_graphql_skip_user_profile_image_extensions_enabled": True,
            "responsive_web_graphql_timeline_navigation_enabled": True
        }
    },
    "LeaveCommunity": {
        "queryId": "zZT5owXUfqlc-bBDulvUcA",
        "variables": {},
        "features": {
            "responsive_web_twitter_blue_verified_badge_is_enabled": True,
            "responsive_web_graphql_exclude_directive_enabled": True,
            "verified_phone_label_enabled": True,
            "responsive_web_graphql_skip_user_profile_image_extensions_enabled": True,
            "responsive_web_graphql_timeline_navigation_enabled": True
        }
    },
    "CommunityMemberRelationshipTypeahead": {
        "queryId": "npEFiYc3sCX-YDHZ1B69nw",
        "variables": {},
        "features": {
            "responsive_web_twitter_blue_verified_badge_is_enabled": True
        }
    },
    "CommunityModerationKeepTweet": {
        "queryId": "rQAQ-rOuZ5Rco0BX_04PvQ",
        "variables": {},
        "features": {
            "responsive_web_twitter_blue_verified_badge_is_enabled": True,
            "responsive_web_graphql_exclude_directive_enabled": True,
            "verified_phone_label_enabled": True,
            "responsive_web_graphql_skip_user_profile_image_extensions_enabled": True,
            "responsive_web_graphql_timeline_navigation_enabled": True
        }
    },
    "CommunityModerationTweetCasesSlice": {
        "queryId": "UZX0jK5-lu00iwnhKW0UNQ",
        "variables": {},
        "features": {
            "tweetypie_unmention_optimization_enabled": True,
            "vibe_api_enabled": True,
            "responsive_web_edit_tweet_api_enabled": True,
            "graphql_is_translatable_rweb_tweet_is_translatable_enabled": True,
            "view_counts_everywhere_api_enabled": True,
            "longform_notetweets_consumption_enabled": True,
            "tweet_awards_web_tipping_enabled": True,
            "freedom_of_speech_not_reach_fetch_enabled": True,
            "standardized_nudges_misinfo": True,
            "tweet_with_visibility_results_prefer_gql_limited_actions_policy_enabled": True,
            "interactive_text_enabled": True,
            "responsive_web_text_conversations_enabled": True,
            "longform_notetweets_richtext_consumption_enabled": True,
            "responsive_web_twitter_blue_verified_badge_is_enabled": True,
            "responsive_web_graphql_exclude_directive_enabled": True,
            "verified_phone_label_enabled": True,
            "responsive_web_graphql_skip_user_profile_image_extensions_enabled": True,
            "responsive_web_graphql_timeline_navigation_enabled": True,
            "responsive_web_enhance_cards_enabled": True
        }
    },
    "CommunityRemoveBannerMedia": {
        "queryId": "wntlkO39ggnplYowqbbSvw",
        "variables": {},
        "features": {
            "responsive_web_twitter_blue_verified_badge_is_enabled": True,
            "responsive_web_graphql_exclude_directive_enabled": True,
            "verified_phone_label_enabled": True,
            "responsive_web_graphql_skip_user_profile_image_extensions_enabled": True,
            "responsive_web_graphql_timeline_navigation_enabled": True
        }
    },
    "CommunityRemoveRule": {
        "queryId": "SmX6I1rX0PyvsEcE-8Y-LA",
        "variables": {},
        "features": {
            "responsive_web_twitter_blue_verified_badge_is_enabled": True,
            "responsive_web_graphql_exclude_directive_enabled": True,
            "verified_phone_label_enabled": True,
            "responsive_web_graphql_skip_user_profile_image_extensions_enabled": True,
            "responsive_web_graphql_timeline_navigation_enabled": True
        }
    },
    "CommunityReorderRules": {
        "queryId": "SlND0s8g7vaWfR5bomaWiQ",
        "variables": {},
        "features": {
            "responsive_web_twitter_blue_verified_badge_is_enabled": True,
            "responsive_web_graphql_exclude_directive_enabled": True,
            "verified_phone_label_enabled": True,
            "responsive_web_graphql_skip_user_profile_image_extensions_enabled": True,
            "responsive_web_graphql_timeline_navigation_enabled": True
        }
    },
    "RequestToJoinCommunity": {
        "queryId": "fxoBRimnPBZde7Jy7oX8Vg",
        "variables": {},
        "features": {
            "responsive_web_twitter_blue_verified_badge_is_enabled": True,
            "responsive_web_graphql_exclude_directive_enabled": True,
            "verified_phone_label_enabled": True,
            "responsive_web_graphql_skip_user_profile_image_extensions_enabled": True,
            "responsive_web_graphql_timeline_navigation_enabled": True
        }
    },
    "CommunityTweetsRankedTimeline": {
        "queryId": "um0FTQcrthAVr6X_50O5Qw",
        "variables": {},
        "features": {
            "responsive_web_twitter_blue_verified_badge_is_enabled": True,
            "responsive_web_graphql_exclude_directive_enabled": True,
            "verified_phone_label_enabled": True,
            "responsive_web_graphql_timeline_navigation_enabled": True,
            "responsive_web_graphql_skip_user_profile_image_extensions_enabled": True,
            "tweetypie_unmention_optimization_enabled": True,
            "vibe_api_enabled": True,
            "responsive_web_edit_tweet_api_enabled": True,
            "graphql_is_translatable_rweb_tweet_is_translatable_enabled": True,
            "view_counts_everywhere_api_enabled": True,
            "longform_notetweets_consumption_enabled": True,
            "tweet_awards_web_tipping_enabled": True,
            "freedom_of_speech_not_reach_fetch_enabled": True,
            "standardized_nudges_misinfo": True,
            "tweet_with_visibility_results_prefer_gql_limited_actions_policy_enabled": True,
            "interactive_text_enabled": True,
            "responsive_web_text_conversations_enabled": True,
            "longform_notetweets_richtext_consumption_enabled": True,
            "responsive_web_enhance_cards_enabled": True
        }
    },
    "CommunityTweetsTimeline": {
        "queryId": "pJHAToy6j1znp36NntvwDA",
        "variables": {},
        "features": {
            "responsive_web_twitter_blue_verified_badge_is_enabled": True,
            "responsive_web_graphql_exclude_directive_enabled": True,
            "verified_phone_label_enabled": True,
            "responsive_web_graphql_timeline_navigation_enabled": True,
            "responsive_web_graphql_skip_user_profile_image_extensions_enabled": True,
            "tweetypie_unmention_optimization_enabled": True,
            "vibe_api_enabled": True,
            "responsive_web_edit_tweet_api_enabled": True,
            "graphql_is_translatable_rweb_tweet_is_translatable_enabled": True,
            "view_counts_everywhere_api_enabled": True,
            "longform_notetweets_consumption_enabled": True,
            "tweet_awards_web_tipping_enabled": True,
            "freedom_of_speech_not_reach_fetch_enabled": True,
            "standardized_nudges_misinfo": True,
            "tweet_with_visibility_results_prefer_gql_limited_actions_policy_enabled": True,
            "interactive_text_enabled": True,
            "responsive_web_text_conversations_enabled": True,
            "longform_notetweets_richtext_consumption_enabled": True,
            "responsive_web_enhance_cards_enabled": True
        }
    },
    "CommunityUpdateRole": {
        "queryId": "--KsROq_U4xbD_wd0ILuzg",
        "variables": {},
        "features": {
            "responsive_web_twitter_blue_verified_badge_is_enabled": True,
            "responsive_web_graphql_exclude_directive_enabled": True,
            "verified_phone_label_enabled": True,
            "responsive_web_graphql_skip_user_profile_image_extensions_enabled": True,
            "responsive_web_graphql_timeline_navigation_enabled": True
        }
    },
    "CommunityUserInvite": {
        "queryId": "el2xSrgrXBxyWvbz193qaA",
        "variables": {},
        "features": {
            "responsive_web_twitter_blue_verified_badge_is_enabled": True
        }
    },
    "CommunityUserRelationshipTypeahead": {
        "queryId": "C9CUCfAvlaMEhJBmM2hZkg",
        "variables": {},
        "features": {
            "responsive_web_twitter_blue_verified_badge_is_enabled": True
        }
    },
    "ConnectTabTimeline": {
        "queryId": "vtzw9bIas-AhHgJTnYih-A",
        "variables": {},
        "features": {
            "responsive_web_twitter_blue_verified_badge_is_enabled": True,
            "responsive_web_graphql_exclude_directive_enabled": True,
            "verified_phone_label_enabled": True,
            "responsive_web_graphql_timeline_navigation_enabled": True,
            "responsive_web_graphql_skip_user_profile_image_extensions_enabled": True,
            "tweetypie_unmention_optimization_enabled": True,
            "vibe_api_enabled": True,
            "responsive_web_edit_tweet_api_enabled": True,
            "graphql_is_translatable_rweb_tweet_is_translatable_enabled": True,
            "view_counts_everywhere_api_enabled": True,
            "longform_notetweets_consumption_enabled": True,
            "tweet_awards_web_tipping_enabled": True,
            "freedom_of_speech_not_reach_fetch_enabled": True,
            "standardized_nudges_misinfo": True,
            "tweet_with_visibility_results_prefer_gql_limited_actions_policy_enabled": True,
            "interactive_text_enabled": True,
            "responsive_web_text_conversations_enabled": True,
            "longform_notetweets_richtext_consumption_enabled": True,
            "responsive_web_enhance_cards_enabled": True
        }
    },
    "ConversationControlChange": {
        "queryId": "hb1elGcj6769uT8qVYqtjw",
        "variables": {},
        "features": {}
    },
    "ConversationControlDelete": {
        "queryId": "OoMO_aSZ1ZXjegeamF9QmA",
        "variables": {},
        "features": {}
    },
    "ConvertRitoSuggestedActions": {
        "queryId": "2njnYoE69O2jdUM7KMEnDw",
        "variables": {},
        "features": {}
    },
    "CreateBookmark": {
        "queryId": "aoDbu3RHznuiSkQ9aNM67Q",
        "variables": {
            "tweet_id": None,
        },
        "features": {}
    },
    "createBookmarkFolder": {
        "queryId": "6Xxqpq8TM_CREYiuof_h5w",
        "variables": {},
        "features": {}
    },
    "CreateCustomerPortalSession": {
        "queryId": "2LHXrd1uYeaMWhciZgPZFw",
        "variables": {},
        "features": {}
    },
    "CreateDraftTweet": {
        "queryId": "cH9HZWz_EW9gnswvA4ZRiQ",
        "variables": {},
        "features": {}
    },
    "CreateNoteTweet": {
        "queryId": "Pyx6nga4XtTVhfTh1gtX1A",
        "variables": {},
        "features": {
            "tweetypie_unmention_optimization_enabled": True,
            "vibe_api_enabled": True,
            "responsive_web_edit_tweet_api_enabled": True,
            "graphql_is_translatable_rweb_tweet_is_translatable_enabled": True,
            "view_counts_everywhere_api_enabled": True,
            "longform_notetweets_consumption_enabled": True,
            "tweet_awards_web_tipping_enabled": True,
            "interactive_text_enabled": True,
            "responsive_web_text_conversations_enabled": True,
            "longform_notetweets_richtext_consumption_enabled": True,
            "responsive_web_twitter_blue_verified_badge_is_enabled": True,
            "responsive_web_graphql_exclude_directive_enabled": True,
            "verified_phone_label_enabled": True,
            "freedom_of_speech_not_reach_fetch_enabled": True,
            "standardized_nudges_misinfo": True,
            "tweet_with_visibility_results_prefer_gql_limited_actions_policy_enabled": True,
            "responsive_web_graphql_timeline_navigation_enabled": True,
            "responsive_web_graphql_skip_user_profile_image_extensions_enabled": True,
            "responsive_web_enhance_cards_enabled": True
        }
    },
    "CreateRetweet": {
        "queryId": "ojPdsZsimiJrUGLR1sjUtA",
        "variables": {
            "tweet_id": None,
            "dark_request": False
        },
        "features": {}
    },
    "CreateScheduledTweet": {
        "queryId": "LCVzRQGxOaGnOnYH01NQXg",
        "variables": {
            "post_tweet_request": {
                "auto_populate_reply_metadata": False,
                "status": None,
                "exclude_reply_user_ids": [],
                "media_ids": []
            },
            "execute_at": None
        },
        "features": {}
    },
    "CreateTrustedFriendsList": {
        "queryId": "2tP8XUYeLHKjq5RHvuvpZw",
        "variables": {},
        "features": {}
    },
    "CreateTweet": {
        "queryId": "t16L8hse5wgpc4iKx4p3zw",
        "variables": {
            "tweet_text": None,
            "dark_request": False,
            "media": {
                "media_entities": [],
                "possibly_sensitive": False
            },
            "withDownvotePerspective": False,
            "withReactionsMetadata": False,
            "withReactionsPerspective": False,
            "withSuperFollowsTweetFields": True,
            "withSuperFollowsUserFields": True,
            "semantic_annotation_ids": []
        },
        "features": {
            "tweetypie_unmention_optimization_enabled": True,
            "vibe_api_enabled": True,
            "responsive_web_edit_tweet_api_enabled": True,
            "graphql_is_translatable_rweb_tweet_is_translatable_enabled": True,
            "view_counts_everywhere_api_enabled": True,
            "longform_notetweets_consumption_enabled": True,
            "tweet_awards_web_tipping_enabled": False,
            "interactive_text_enabled": True,
            "responsive_web_text_conversations_enabled": False,
            "longform_notetweets_richtext_consumption_enabled": False,
            "responsive_web_twitter_blue_verified_badge_is_enabled": True,
            "responsive_web_graphql_exclude_directive_enabled": True,
            "verified_phone_label_enabled": False,
            "freedom_of_speech_not_reach_fetch_enabled": False,
            "standardized_nudges_misinfo": True,
            "tweet_with_visibility_results_prefer_gql_limited_actions_policy_enabled": False,
            "responsive_web_graphql_timeline_navigation_enabled": True,
            "responsive_web_graphql_skip_user_profile_image_extensions_enabled": False,
            "responsive_web_enhance_cards_enabled": False
        }
    },
    "CreateTweetDownvote": {
        "queryId": "Eo65jl-gww30avDgrXvhUA",
        "variables": {},
        "features": {}
    },
    "CreateTweetReaction": {
        "queryId": "D7M6X3h4-mJE8UB1Ap3_dQ",
        "variables": {},
        "features": {}
    },
    "DataSaverMode": {
        "queryId": "xF6sXnKJfS2AOylzxRjf6A",
        "variables": {
            "device_id": "Linux/Chrome"
        },
        "features": {}
    },
    "WriteDataSaverPreferences": {
        "queryId": "H03etWvZGz41YASxAU2YPg",
        "variables": {},
        "features": {}
    },
    "SetDefault": {
        "queryId": "QEMLEzEMzoPNbeauKCCLbg",
        "variables": {},
        "features": {}
    },
    "BookmarksAllDelete": {
        "queryId": "skiACZKC1GDYli-M8RzEPQ",
        "variables": {},
        "features": {}
    },
    "DeleteBookmark": {
        "queryId": "Wlmlj2-xzyS1GN3a6cj-mQ",
        "variables": {
            "tweet_id": None
        },
        "features": {}
    },
    "DeleteBookmarkFolder": {
        "queryId": "2UTTsO-6zs93XqlEUZPsSg",
        "variables": {},
        "features": {}
    },
    "DeleteDraftTweet": {
        "queryId": "bkh9G3FGgTldS9iTKWWYYw",
        "variables": {},
        "features": {}
    },
    "DeletePaymentMethod": {
        "queryId": "VaaLGwK5KNLoc7wsOmp4uw",
        "variables": {},
        "features": {}
    },
    "DeleteRetweet": {
        "queryId": "iQtK4dl5hBmXewYZuEOKVw",
        "variables": {
            "source_tweet_id": None,
            "dark_request": False
        },
        "features": {}
    },
    "DeleteScheduledTweet": {
        "queryId": "CTOVqej0JBXAZSwkp1US0g",
        "variables": {
            "scheduled_tweet_id": None,
        },
        "features": {}
    },
    "DeleteTweet": {
        "variables": {
            "tweet_id": "1633699974079983616",
            "dark_request": False
        },
        "queryId": "VaenaVgh5q5ih7kvyVjgtg",
        "features": {}
    },
    "DeleteTweetDownvote": {
        "queryId": "VNEvEGXaUAMfiExP8Tbezw",
        "variables": {},
        "features": {}
    },
    "DeleteTweetReaction": {
        "queryId": "GKwK0Rj4EdkfwdHQMZTpuw",
        "variables": {},
        "features": {}
    },
    "DisableUserAccountLabel": {
        "queryId": "_ckHEj05gan2VfNHG6thBA",
        "variables": {},
        "features": {}
    },
    "DisableVerifiedPhoneLabel": {
        "queryId": "g2m0pAOamawNtVIfjXNMJg",
        "variables": {},
        "features": {}
    },
    "DismissRitoSuggestedAction": {
        "queryId": "jYvwa61cv3NwNP24iUru6g",
        "variables": {},
        "features": {}
    },
    "DmAllSearchSlice": {
        "queryId": "O9Sqb8IjJhtK7gzfUs5eyw",
        "variables": {},
        "features": {
            "responsive_web_twitter_blue_verified_badge_is_enabled": True,
            "responsive_web_graphql_exclude_directive_enabled": True,
            "verified_phone_label_enabled": True,
            "responsive_web_graphql_skip_user_profile_image_extensions_enabled": True,
            "responsive_web_graphql_timeline_navigation_enabled": True
        }
    },
    "DmGroupSearchSlice": {
        "queryId": "5zpY1dCR-8NyxQJS_CFJoQ",
        "variables": {},
        "features": {}
    },
    "DmMutedTimeline": {
        "queryId": "L7tN_77Tk950tMAy7sFCkA",
        "variables": {},
        "features": {
            "responsive_web_twitter_blue_verified_badge_is_enabled": True,
            "responsive_web_graphql_exclude_directive_enabled": True,
            "verified_phone_label_enabled": True,
            "responsive_web_graphql_timeline_navigation_enabled": True,
            "responsive_web_graphql_skip_user_profile_image_extensions_enabled": True,
            "tweetypie_unmention_optimization_enabled": True,
            "vibe_api_enabled": True,
            "responsive_web_edit_tweet_api_enabled": True,
            "graphql_is_translatable_rweb_tweet_is_translatable_enabled": True,
            "view_counts_everywhere_api_enabled": True,
            "longform_notetweets_consumption_enabled": True,
            "tweet_awards_web_tipping_enabled": True,
            "freedom_of_speech_not_reach_fetch_enabled": True,
            "standardized_nudges_misinfo": True,
            "tweet_with_visibility_results_prefer_gql_limited_actions_policy_enabled": True,
            "interactive_text_enabled": True,
            "responsive_web_text_conversations_enabled": True,
            "longform_notetweets_richtext_consumption_enabled": True,
            "responsive_web_enhance_cards_enabled": True
        }
    },
    "DmNsfwMediaFilterUpdate": {
        "queryId": "of_N6O33zfyD4qsFJMYFxA",
        "variables": {},
        "features": {}
    },
    "DmPeopleSearchSlice": {
        "queryId": "xYSm8m5kJnzm_gFCn5GH-w",
        "variables": {},
        "features": {}
    },
    "EditBookmarkFolder": {
        "queryId": "a6kPp1cS1Dgbsjhapz1PNw",
        "variables": {},
        "features": {}
    },
    "EditDraftTweet": {
        "queryId": "JIeXE-I6BZXHfxsgOkyHYQ",
        "variables": {},
        "features": {}
    },
    "EditScheduledTweet": {
        "queryId": "_mHkQ5LHpRRjSXKOcG6eZw",
        "variables": {},
        "features": {}
    },
    "WriteEmailNotificationSettings": {
        "queryId": "2qKKYFQift8p5-J1k6kqxQ",
        "variables": {},
        "features": {}
    },
    "EnableLoggedOutWebNotifications": {
        "queryId": "BqIHKmwZKtiUBPi07jKctg",
        "variables": {},
        "features": {}
    },
    "EnableVerifiedPhoneLabel": {
        "queryId": "C3RJFfMsb_KcEytpKmRRkw",
        "variables": {},
        "features": {}
    },
    "FavoriteTweet": {
        "queryId": "lI07N6Otwv1PhnEgXILM7A",
        "variables": {
            "tweet_id": None
        },
        "features": {}
    },
    "Favoriters": {
        "queryId": "XRRjv1-uj1HZn3o324etOQ",
        "variables": {
            "tweetId": None,
            "count": 1000,
            "includePromotedContent": True,
            "withSuperFollowsUserFields": True,
            "withDownvotePerspective": False,
            "withReactionsMetadata": False,
            "withReactionsPerspective": False,
            "withSuperFollowsTweetFields": True
        },
        "features": {
            "responsive_web_twitter_blue_verified_badge_is_enabled": True,
            "responsive_web_graphql_exclude_directive_enabled": True,
            "verified_phone_label_enabled": True,
            "responsive_web_graphql_timeline_navigation_enabled": True,
            "responsive_web_graphql_skip_user_profile_image_extensions_enabled": True,
            "tweetypie_unmention_optimization_enabled": True,
            "vibe_api_enabled": True,
            "responsive_web_edit_tweet_api_enabled": True,
            "graphql_is_translatable_rweb_tweet_is_translatable_enabled": True,
            "view_counts_everywhere_api_enabled": True,
            "longform_notetweets_consumption_enabled": True,
            "tweet_awards_web_tipping_enabled": True,
            "freedom_of_speech_not_reach_fetch_enabled": True,
            "standardized_nudges_misinfo": True,
            "tweet_with_visibility_results_prefer_gql_limited_actions_policy_enabled": True,
            "interactive_text_enabled": True,
            "responsive_web_text_conversations_enabled": True,
            "longform_notetweets_richtext_consumption_enabled": True,
            "responsive_web_enhance_cards_enabled": True
        }
    },
    "FeatureSettingsUpdate": {
        "queryId": "-btar_vkBwWA7s3YWfp_9g",
        "variables": {},
        "features": {}
    },
    "Followers": {
        "queryId": "pd8Tt1qUz1YWrICegqZ8cw",
        "variables": {
            "userId": None,
            "count": 1000,
            "includePromotedContent": True,
            "withDownvotePerspective": False,
            "withReactionsMetadata": False,
            "withReactionsPerspective": False,
            "withSuperFollowsTweetFields": True,
            "withSuperFollowsUserFields": True
        },
        "features": {
            "responsive_web_twitter_blue_verified_badge_is_enabled": True,
            "responsive_web_graphql_exclude_directive_enabled": True,
            "verified_phone_label_enabled": True,
            "responsive_web_graphql_timeline_navigation_enabled": True,
            "responsive_web_graphql_skip_user_profile_image_extensions_enabled": True,
            "tweetypie_unmention_optimization_enabled": True,
            "vibe_api_enabled": True,
            "responsive_web_edit_tweet_api_enabled": True,
            "graphql_is_translatable_rweb_tweet_is_translatable_enabled": True,
            "view_counts_everywhere_api_enabled": True,
            "longform_notetweets_consumption_enabled": True,
            "tweet_awards_web_tipping_enabled": True,
            "freedom_of_speech_not_reach_fetch_enabled": True,
            "standardized_nudges_misinfo": True,
            "tweet_with_visibility_results_prefer_gql_limited_actions_policy_enabled": True,
            "interactive_text_enabled": True,
            "responsive_web_text_conversations_enabled": True,
            "longform_notetweets_richtext_consumption_enabled": True,
            "responsive_web_enhance_cards_enabled": True
        }
    },
    "FollowersYouKnow": {
        "queryId": "95iQJXlI0_dFs_Ni6Ann9Q",
        "variables": {},
        "features": {
            "responsive_web_twitter_blue_verified_badge_is_enabled": True,
            "responsive_web_graphql_exclude_directive_enabled": True,
            "verified_phone_label_enabled": True,
            "responsive_web_graphql_timeline_navigation_enabled": True,
            "responsive_web_graphql_skip_user_profile_image_extensions_enabled": True,
            "tweetypie_unmention_optimization_enabled": True,
            "vibe_api_enabled": True,
            "responsive_web_edit_tweet_api_enabled": True,
            "graphql_is_translatable_rweb_tweet_is_translatable_enabled": True,
            "view_counts_everywhere_api_enabled": True,
            "longform_notetweets_consumption_enabled": True,
            "tweet_awards_web_tipping_enabled": True,
            "freedom_of_speech_not_reach_fetch_enabled": True,
            "standardized_nudges_misinfo": True,
            "tweet_with_visibility_results_prefer_gql_limited_actions_policy_enabled": True,
            "interactive_text_enabled": True,
            "responsive_web_text_conversations_enabled": True,
            "longform_notetweets_richtext_consumption_enabled": True,
            "responsive_web_enhance_cards_enabled": True
        }
    },
    "Following": {
        "queryId": "wjvx62Hye2dGVvnvVco0xA",
        "variables": {
            "userId": None,
            "count": 1000,
            "includePromotedContent": True,
            "withDownvotePerspective": False,
            "withReactionsMetadata": False,
            "withReactionsPerspective": False,
            "withSuperFollowsTweetFields": True,
            "withSuperFollowsUserFields": True
        },
        "features": {
            "responsive_web_twitter_blue_verified_badge_is_enabled": True,
            "responsive_web_graphql_exclude_directive_enabled": True,
            "verified_phone_label_enabled": True,
            "responsive_web_graphql_timeline_navigation_enabled": True,
            "responsive_web_graphql_skip_user_profile_image_extensions_enabled": True,
            "tweetypie_unmention_optimization_enabled": True,
            "vibe_api_enabled": True,
            "responsive_web_edit_tweet_api_enabled": True,
            "graphql_is_translatable_rweb_tweet_is_translatable_enabled": True,
            "view_counts_everywhere_api_enabled": True,
            "longform_notetweets_consumption_enabled": True,
            "tweet_awards_web_tipping_enabled": True,
            "freedom_of_speech_not_reach_fetch_enabled": True,
            "standardized_nudges_misinfo": True,
            "tweet_with_visibility_results_prefer_gql_limited_actions_policy_enabled": True,
            "interactive_text_enabled": True,
            "responsive_web_text_conversations_enabled": True,
            "longform_notetweets_richtext_consumption_enabled": True,
            "responsive_web_enhance_cards_enabled": True
        }
    },
    "ForYouExplore": {
        "queryId": "wVEXnyTWzQlEsIuLq_D3tw",
        "variables": {},
        "features": {
            "responsive_web_twitter_blue_verified_badge_is_enabled": True,
            "responsive_web_graphql_exclude_directive_enabled": True,
            "verified_phone_label_enabled": True,
            "responsive_web_graphql_timeline_navigation_enabled": True,
            "responsive_web_graphql_skip_user_profile_image_extensions_enabled": True,
            "tweetypie_unmention_optimization_enabled": True,
            "vibe_api_enabled": True,
            "responsive_web_edit_tweet_api_enabled": True,
            "graphql_is_translatable_rweb_tweet_is_translatable_enabled": True,
            "view_counts_everywhere_api_enabled": True,
            "longform_notetweets_consumption_enabled": True,
            "tweet_awards_web_tipping_enabled": True,
            "freedom_of_speech_not_reach_fetch_enabled": True,
            "standardized_nudges_misinfo": True,
            "tweet_with_visibility_results_prefer_gql_limited_actions_policy_enabled": True,
            "interactive_text_enabled": True,
            "responsive_web_text_conversations_enabled": True,
            "longform_notetweets_richtext_consumption_enabled": True,
            "responsive_web_enhance_cards_enabled": True
        }
    },
    "GenericTimelineById": {
        "queryId": "K3sJPgCxVJWZSc9jyJJXsA",
        "variables": {},
        "features": {
            "responsive_web_twitter_blue_verified_badge_is_enabled": True,
            "responsive_web_graphql_exclude_directive_enabled": True,
            "verified_phone_label_enabled": True,
            "responsive_web_graphql_timeline_navigation_enabled": True,
            "responsive_web_graphql_skip_user_profile_image_extensions_enabled": True,
            "tweetypie_unmention_optimization_enabled": True,
            "vibe_api_enabled": True,
            "responsive_web_edit_tweet_api_enabled": True,
            "graphql_is_translatable_rweb_tweet_is_translatable_enabled": True,
            "view_counts_everywhere_api_enabled": True,
            "longform_notetweets_consumption_enabled": True,
            "tweet_awards_web_tipping_enabled": True,
            "freedom_of_speech_not_reach_fetch_enabled": True,
            "standardized_nudges_misinfo": True,
            "tweet_with_visibility_results_prefer_gql_limited_actions_policy_enabled": True,
            "interactive_text_enabled": True,
            "responsive_web_text_conversations_enabled": True,
            "longform_notetweets_richtext_consumption_enabled": True,
            "responsive_web_enhance_cards_enabled": True
        }
    },
    "GraphQLError": {
        "queryId": "2V2W3HIBuMW83vEMtfo_Rg",
        "variables": {},
        "features": {}
    },
    "HomeLatestTimeline": {
        "queryId": "mBo3f9s6XlntJE3nLv09iQ",
        "variables": {
            "count": 1000,
            "includePromotedContent": True,
            "latestControlAvailable": True,
            "requestContext": "launch",
            "withSuperFollowsUserFields": True,
            "withDownvotePerspective": False,
            "withReactionsMetadata": False,
            "withReactionsPerspective": False,
            "withSuperFollowsTweetFields": True
        },
        "features": {
            "responsive_web_twitter_blue_verified_badge_is_enabled": True,
            "responsive_web_graphql_exclude_directive_enabled": True,
            "verified_phone_label_enabled": True,
            "responsive_web_graphql_timeline_navigation_enabled": True,
            "responsive_web_graphql_skip_user_profile_image_extensions_enabled": True,
            "tweetypie_unmention_optimization_enabled": True,
            "vibe_api_enabled": True,
            "responsive_web_edit_tweet_api_enabled": True,
            "graphql_is_translatable_rweb_tweet_is_translatable_enabled": True,
            "view_counts_everywhere_api_enabled": True,
            "longform_notetweets_consumption_enabled": True,
            "tweet_awards_web_tipping_enabled": True,
            "freedom_of_speech_not_reach_fetch_enabled": True,
            "standardized_nudges_misinfo": True,
            "tweet_with_visibility_results_prefer_gql_limited_actions_policy_enabled": True,
            "interactive_text_enabled": True,
            "responsive_web_text_conversations_enabled": True,
            "longform_notetweets_richtext_consumption_enabled": True,
            "responsive_web_enhance_cards_enabled": True
        }
    },
    "HomeTimeline": {
        "queryId": "u5XGoPEa9-Hb30zpGz3Yrg",
        "variables": {
            "count": 1000,
            "includePromotedContent": True,
            "latestControlAvailable": True,
            "requestContext": "launch",
            "withCommunity": True,
            "withSuperFollowsUserFields": True,
            "withDownvotePerspective": False,
            "withReactionsMetadata": False,
            "withReactionsPerspective": False,
            "withSuperFollowsTweetFields": True
        },
        "features": {
            "responsive_web_twitter_blue_verified_badge_is_enabled": True,
            "responsive_web_graphql_exclude_directive_enabled": True,
            "verified_phone_label_enabled": True,
            "responsive_web_graphql_timeline_navigation_enabled": True,
            "responsive_web_graphql_skip_user_profile_image_extensions_enabled": True,
            "tweetypie_unmention_optimization_enabled": True,
            "vibe_api_enabled": True,
            "responsive_web_edit_tweet_api_enabled": True,
            "graphql_is_translatable_rweb_tweet_is_translatable_enabled": True,
            "view_counts_everywhere_api_enabled": True,
            "longform_notetweets_consumption_enabled": True,
            "tweet_awards_web_tipping_enabled": True,
            "freedom_of_speech_not_reach_fetch_enabled": True,
            "standardized_nudges_misinfo": True,
            "tweet_with_visibility_results_prefer_gql_limited_actions_policy_enabled": True,
            "interactive_text_enabled": True,
            "responsive_web_text_conversations_enabled": True,
            "longform_notetweets_richtext_consumption_enabled": True,
            "responsive_web_enhance_cards_enabled": True
        }
    },
    "ImmersiveMedia": {
        "queryId": "7P_Y2m7_NkEnge7eCeW-cw",
        "variables": {},
        "features": {
            "responsive_web_twitter_blue_verified_badge_is_enabled": True,
            "responsive_web_graphql_exclude_directive_enabled": True,
            "verified_phone_label_enabled": True,
            "responsive_web_graphql_timeline_navigation_enabled": True,
            "responsive_web_graphql_skip_user_profile_image_extensions_enabled": True,
            "tweetypie_unmention_optimization_enabled": True,
            "vibe_api_enabled": True,
            "responsive_web_edit_tweet_api_enabled": True,
            "graphql_is_translatable_rweb_tweet_is_translatable_enabled": True,
            "view_counts_everywhere_api_enabled": True,
            "longform_notetweets_consumption_enabled": True,
            "tweet_awards_web_tipping_enabled": True,
            "freedom_of_speech_not_reach_fetch_enabled": True,
            "standardized_nudges_misinfo": True,
            "tweet_with_visibility_results_prefer_gql_limited_actions_policy_enabled": True,
            "interactive_text_enabled": True,
            "responsive_web_text_conversations_enabled": True,
            "longform_notetweets_richtext_consumption_enabled": True,
            "responsive_web_enhance_cards_enabled": True
        }
    },
    "Likes": {
        "queryId": "nYrjBgnUWQFt_tRyCGatZA",
        "variables": {
            "userId": None,
            "count": 1000,
            "includePromotedContent": True,
            "withSuperFollowsUserFields": True,
            "withDownvotePerspective": False,
            "withReactionsMetadata": False,
            "withReactionsPerspective": False,
            "withSuperFollowsTweetFields": True,
            "withClientEventToken": False,
            "withBirdwatchNotes": False,
            "withVoice": True,
            "withV2Timeline": True
        },
        "features": {
            "responsive_web_twitter_blue_verified_badge_is_enabled": True,
            "responsive_web_graphql_exclude_directive_enabled": True,
            "verified_phone_label_enabled": True,
            "responsive_web_graphql_timeline_navigation_enabled": True,
            "responsive_web_graphql_skip_user_profile_image_extensions_enabled": True,
            "tweetypie_unmention_optimization_enabled": True,
            "vibe_api_enabled": True,
            "responsive_web_edit_tweet_api_enabled": True,
            "graphql_is_translatable_rweb_tweet_is_translatable_enabled": True,
            "view_counts_everywhere_api_enabled": True,
            "longform_notetweets_consumption_enabled": True,
            "tweet_awards_web_tipping_enabled": True,
            "freedom_of_speech_not_reach_fetch_enabled": True,
            "standardized_nudges_misinfo": True,
            "tweet_with_visibility_results_prefer_gql_limited_actions_policy_enabled": True,
            "interactive_text_enabled": True,
            "responsive_web_text_conversations_enabled": True,
            "longform_notetweets_richtext_consumption_enabled": True,
            "responsive_web_enhance_cards_enabled": True
        }
    },
    "ListAddMember": {
        "queryId": "P8tyfv2_0HzofrB5f6_ugw",
        "variables": {
            "listId": None,
            "userId": None,
            "withSuperFollowsUserFields": False,
        },
        "features": {
            "responsive_web_twitter_blue_verified_badge_is_enabled": True,
            "responsive_web_graphql_exclude_directive_enabled": True,
            "verified_phone_label_enabled": True,
            "responsive_web_graphql_skip_user_profile_image_extensions_enabled": True,
            "responsive_web_graphql_timeline_navigation_enabled": True
        }
    },
    "DeleteListBanner": {
        "queryId": "-bOKetDVCMl20qXn7YDXIA",
        "variables": {
            "listId": None,
            "withSuperFollowsUserFields": False,
        },
        "features": {
            "responsive_web_twitter_blue_verified_badge_is_enabled": True,
            "responsive_web_graphql_exclude_directive_enabled": True,
            "verified_phone_label_enabled": True,
            "responsive_web_graphql_skip_user_profile_image_extensions_enabled": True,
            "responsive_web_graphql_timeline_navigation_enabled": True
        }
    },
    "EditListBanner": {
        "queryId": "Uk0ZwKSMYng56aQdeJD1yw",
        "variables": {
            "listId": None,
            "mediaId": None,
            "withSuperFollowsUserFields": False,
        },
        "features": {
            "responsive_web_twitter_blue_verified_badge_is_enabled": True,
            "responsive_web_graphql_exclude_directive_enabled": True,
            "verified_phone_label_enabled": True,
            "responsive_web_graphql_skip_user_profile_image_extensions_enabled": True,
            "responsive_web_graphql_timeline_navigation_enabled": True
        }
    },
    "ListBySlug": {
        "queryId": "i08_qAU5nG5EkjnbcCeg0g",
        "variables": {},
        "features": {
            "responsive_web_twitter_blue_verified_badge_is_enabled": True,
            "responsive_web_graphql_exclude_directive_enabled": True,
            "verified_phone_label_enabled": True,
            "responsive_web_graphql_skip_user_profile_image_extensions_enabled": True,
            "responsive_web_graphql_timeline_navigation_enabled": True
        }
    },
    "CreateList": {
        "queryId": "hQAsnViq2BrMLbPuQ9umDA",
        "variables": {
            "isPrivate": None,  # True/False
            "name": None,
            "description": None,
            "withSuperFollowsUserFields": True,  # True/False
        },
        "features": {
            "responsive_web_twitter_blue_verified_badge_is_enabled": True,
            "responsive_web_graphql_exclude_directive_enabled": True,
            "verified_phone_label_enabled": True,
            "responsive_web_graphql_skip_user_profile_image_extensions_enabled": True,
            "responsive_web_graphql_timeline_navigation_enabled": True
        }
    },
    "ListCreationRecommendedUsers": {
        "queryId": "v8nSx_ZtU14Q4VK4Ag4aZA",
        "variables": {},
        "features": {
            "responsive_web_twitter_blue_verified_badge_is_enabled": True,
            "responsive_web_graphql_exclude_directive_enabled": True,
            "verified_phone_label_enabled": True,
            "responsive_web_graphql_timeline_navigation_enabled": True,
            "responsive_web_graphql_skip_user_profile_image_extensions_enabled": True,
            "tweetypie_unmention_optimization_enabled": True,
            "vibe_api_enabled": True,
            "responsive_web_edit_tweet_api_enabled": True,
            "graphql_is_translatable_rweb_tweet_is_translatable_enabled": True,
            "view_counts_everywhere_api_enabled": True,
            "longform_notetweets_consumption_enabled": True,
            "tweet_awards_web_tipping_enabled": True,
            "freedom_of_speech_not_reach_fetch_enabled": True,
            "standardized_nudges_misinfo": True,
            "tweet_with_visibility_results_prefer_gql_limited_actions_policy_enabled": True,
            "interactive_text_enabled": True,
            "responsive_web_text_conversations_enabled": True,
            "longform_notetweets_richtext_consumption_enabled": True,
            "responsive_web_enhance_cards_enabled": True
        }
    },
    "DeleteList": {
        "queryId": "UnN9Th1BDbeLjpgjGSpL3Q",
        "variables": {
            "listId": None,
        },
        "features": {}
    },
    "FetchDraftTweets": {
        "queryId": "ZkqIq_xRhiUme0PBJNpRtg",
        "variables": {},
        "features": {}
    },
    "ListEditRecommendedUsers": {
        "queryId": "0kj42oKYT7gL-SBLoxJH6w",
        "variables": {},
        "features": {
            "responsive_web_twitter_blue_verified_badge_is_enabled": True,
            "responsive_web_graphql_exclude_directive_enabled": True,
            "verified_phone_label_enabled": True,
            "responsive_web_graphql_timeline_navigation_enabled": True,
            "responsive_web_graphql_skip_user_profile_image_extensions_enabled": True,
            "tweetypie_unmention_optimization_enabled": True,
            "vibe_api_enabled": True,
            "responsive_web_edit_tweet_api_enabled": True,
            "graphql_is_translatable_rweb_tweet_is_translatable_enabled": True,
            "view_counts_everywhere_api_enabled": True,
            "longform_notetweets_consumption_enabled": True,
            "tweet_awards_web_tipping_enabled": True,
            "freedom_of_speech_not_reach_fetch_enabled": True,
            "standardized_nudges_misinfo": True,
            "tweet_with_visibility_results_prefer_gql_limited_actions_policy_enabled": True,
            "interactive_text_enabled": True,
            "responsive_web_text_conversations_enabled": True,
            "longform_notetweets_richtext_consumption_enabled": True,
            "responsive_web_enhance_cards_enabled": True
        }
    },
    "ListLatestTweetsTimeline": {
        "queryId": "1KstFrRPSljOFXpcQVgplQ",
        "variables": {},
        "features": {
            "responsive_web_twitter_blue_verified_badge_is_enabled": True,
            "responsive_web_graphql_exclude_directive_enabled": True,
            "verified_phone_label_enabled": True,
            "responsive_web_graphql_timeline_navigation_enabled": True,
            "responsive_web_graphql_skip_user_profile_image_extensions_enabled": True,
            "tweetypie_unmention_optimization_enabled": True,
            "vibe_api_enabled": True,
            "responsive_web_edit_tweet_api_enabled": True,
            "graphql_is_translatable_rweb_tweet_is_translatable_enabled": True,
            "view_counts_everywhere_api_enabled": True,
            "longform_notetweets_consumption_enabled": True,
            "tweet_awards_web_tipping_enabled": True,
            "freedom_of_speech_not_reach_fetch_enabled": True,
            "standardized_nudges_misinfo": True,
            "tweet_with_visibility_results_prefer_gql_limited_actions_policy_enabled": True,
            "interactive_text_enabled": True,
            "responsive_web_text_conversations_enabled": True,
            "longform_notetweets_richtext_consumption_enabled": True,
            "responsive_web_enhance_cards_enabled": True
        }
    },
    "ListMembers": {
        "queryId": "FSzYZVLhaaQYkrY7XXHN4g",
        "variables": {},
        "features": {
            "responsive_web_twitter_blue_verified_badge_is_enabled": True,
            "responsive_web_graphql_exclude_directive_enabled": True,
            "verified_phone_label_enabled": True,
            "responsive_web_graphql_timeline_navigation_enabled": True,
            "responsive_web_graphql_skip_user_profile_image_extensions_enabled": True,
            "tweetypie_unmention_optimization_enabled": True,
            "vibe_api_enabled": True,
            "responsive_web_edit_tweet_api_enabled": True,
            "graphql_is_translatable_rweb_tweet_is_translatable_enabled": True,
            "view_counts_everywhere_api_enabled": True,
            "longform_notetweets_consumption_enabled": True,
            "tweet_awards_web_tipping_enabled": True,
            "freedom_of_speech_not_reach_fetch_enabled": True,
            "standardized_nudges_misinfo": True,
            "tweet_with_visibility_results_prefer_gql_limited_actions_policy_enabled": True,
            "interactive_text_enabled": True,
            "responsive_web_text_conversations_enabled": True,
            "longform_notetweets_richtext_consumption_enabled": True,
            "responsive_web_enhance_cards_enabled": True
        }
    },
    "ListMemberships": {
        "queryId": "yTAHAtT8Ez4EDcG3I4Uzew",
        "variables": {},
        "features": {
            "responsive_web_twitter_blue_verified_badge_is_enabled": True,
            "responsive_web_graphql_exclude_directive_enabled": True,
            "verified_phone_label_enabled": True,
            "responsive_web_graphql_timeline_navigation_enabled": True,
            "responsive_web_graphql_skip_user_profile_image_extensions_enabled": True,
            "tweetypie_unmention_optimization_enabled": True,
            "vibe_api_enabled": True,
            "responsive_web_edit_tweet_api_enabled": True,
            "graphql_is_translatable_rweb_tweet_is_translatable_enabled": True,
            "view_counts_everywhere_api_enabled": True,
            "longform_notetweets_consumption_enabled": True,
            "tweet_awards_web_tipping_enabled": True,
            "freedom_of_speech_not_reach_fetch_enabled": True,
            "standardized_nudges_misinfo": True,
            "tweet_with_visibility_results_prefer_gql_limited_actions_policy_enabled": True,
            "interactive_text_enabled": True,
            "responsive_web_text_conversations_enabled": True,
            "longform_notetweets_richtext_consumption_enabled": True,
            "responsive_web_enhance_cards_enabled": True
        }
    },
    "MuteList": {
        "queryId": "ZYyanJsskNUcltu9bliMLA",
        "variables": {},
        "features": {}
    },
    "ListOwnerships": {
        "queryId": "L2Mni5sKnWUbNHcbdndscQ",
        "variables": {},
        "features": {
            "responsive_web_twitter_blue_verified_badge_is_enabled": True,
            "responsive_web_graphql_exclude_directive_enabled": True,
            "verified_phone_label_enabled": True,
            "responsive_web_graphql_timeline_navigation_enabled": True,
            "responsive_web_graphql_skip_user_profile_image_extensions_enabled": True,
            "tweetypie_unmention_optimization_enabled": True,
            "vibe_api_enabled": True,
            "responsive_web_edit_tweet_api_enabled": True,
            "graphql_is_translatable_rweb_tweet_is_translatable_enabled": True,
            "view_counts_everywhere_api_enabled": True,
            "longform_notetweets_consumption_enabled": True,
            "tweet_awards_web_tipping_enabled": True,
            "freedom_of_speech_not_reach_fetch_enabled": True,
            "standardized_nudges_misinfo": True,
            "tweet_with_visibility_results_prefer_gql_limited_actions_policy_enabled": True,
            "interactive_text_enabled": True,
            "responsive_web_text_conversations_enabled": True,
            "longform_notetweets_richtext_consumption_enabled": True,
            "responsive_web_enhance_cards_enabled": True
        }
    },
    "ListPinOne": {
        "queryId": "PdFLmbN9FAT3kxuYphbO6A",
        "variables": {
            "listId": None,
            "withSuperFollowsUserFields": True,
        },
        "features": {
            "responsive_web_twitter_blue_verified_badge_is_enabled": True,
            "responsive_web_graphql_exclude_directive_enabled": True,
            "verified_phone_label_enabled": True,
            "responsive_web_graphql_skip_user_profile_image_extensions_enabled": True,
            "responsive_web_graphql_timeline_navigation_enabled": True
        }
    },
    "ListPins": {
        "queryId": "KwDtNPZP8xL57bCxHCIvOg",
        "variables": {
            "withSuperFollowsUserFields": True
        },
        "features": {
            "responsive_web_twitter_blue_verified_badge_is_enabled": True,
            "responsive_web_graphql_exclude_directive_enabled": True,
            "verified_phone_label_enabled": True,
            "responsive_web_graphql_skip_user_profile_image_extensions_enabled": True,
            "responsive_web_graphql_timeline_navigation_enabled": True
        }
    },
    "ListProductSubscriptions": {
        "queryId": "wwdBYgScze0_Jnan79jEUw",
        "variables": {},
        "features": {}
    },
    "ListByRestId": {
        "queryId": "Bc-6GPUtWnyr3PN0fNffyA",
        "variables": {},
        "features": {
            "responsive_web_twitter_blue_verified_badge_is_enabled": True,
            "responsive_web_graphql_exclude_directive_enabled": True,
            "verified_phone_label_enabled": True,
            "responsive_web_graphql_skip_user_profile_image_extensions_enabled": True,
            "responsive_web_graphql_timeline_navigation_enabled": True
        }
    },
    "ListRankedTweetsTimeline": {
        "queryId": "8L7Yat0LpxTWYLPMKDkiEg",
        "variables": {},
        "features": {
            "responsive_web_twitter_blue_verified_badge_is_enabled": True,
            "responsive_web_graphql_exclude_directive_enabled": True,
            "verified_phone_label_enabled": True,
            "responsive_web_graphql_timeline_navigation_enabled": True,
            "responsive_web_graphql_skip_user_profile_image_extensions_enabled": True,
            "tweetypie_unmention_optimization_enabled": True,
            "vibe_api_enabled": True,
            "responsive_web_edit_tweet_api_enabled": True,
            "graphql_is_translatable_rweb_tweet_is_translatable_enabled": True,
            "view_counts_everywhere_api_enabled": True,
            "longform_notetweets_consumption_enabled": True,
            "tweet_awards_web_tipping_enabled": True,
            "freedom_of_speech_not_reach_fetch_enabled": True,
            "standardized_nudges_misinfo": True,
            "tweet_with_visibility_results_prefer_gql_limited_actions_policy_enabled": True,
            "interactive_text_enabled": True,
            "responsive_web_text_conversations_enabled": True,
            "longform_notetweets_richtext_consumption_enabled": True,
            "responsive_web_enhance_cards_enabled": True
        }
    },
    "ListRemoveMember": {
        "queryId": "DBZowzFN492FFkBPBptCwg",
        "variables": {
            "listId": None,
            "userId": None,
            "withSuperFollowsUserFields": False,
        },
        "features": {
            "responsive_web_twitter_blue_verified_badge_is_enabled": True,
            "responsive_web_graphql_exclude_directive_enabled": True,
            "verified_phone_label_enabled": True,
            "responsive_web_graphql_skip_user_profile_image_extensions_enabled": True,
            "responsive_web_graphql_timeline_navigation_enabled": True
        }
    },
    "ListSubscribe": {
        "queryId": "JZ_OVzM4b32pPufdXa5vgw",
        "variables": {},
        "features": {
            "responsive_web_twitter_blue_verified_badge_is_enabled": True,
            "responsive_web_graphql_exclude_directive_enabled": True,
            "verified_phone_label_enabled": True,
            "responsive_web_graphql_skip_user_profile_image_extensions_enabled": True,
            "responsive_web_graphql_timeline_navigation_enabled": True
        }
    },
    "ListSubscribers": {
        "queryId": "fCOx7ELrPOcZAK_qZuiHYQ",
        "variables": {},
        "features": {
            "responsive_web_twitter_blue_verified_badge_is_enabled": True,
            "responsive_web_graphql_exclude_directive_enabled": True,
            "verified_phone_label_enabled": True,
            "responsive_web_graphql_timeline_navigation_enabled": True,
            "responsive_web_graphql_skip_user_profile_image_extensions_enabled": True,
            "tweetypie_unmention_optimization_enabled": True,
            "vibe_api_enabled": True,
            "responsive_web_edit_tweet_api_enabled": True,
            "graphql_is_translatable_rweb_tweet_is_translatable_enabled": True,
            "view_counts_everywhere_api_enabled": True,
            "longform_notetweets_consumption_enabled": True,
            "tweet_awards_web_tipping_enabled": True,
            "freedom_of_speech_not_reach_fetch_enabled": True,
            "standardized_nudges_misinfo": True,
            "tweet_with_visibility_results_prefer_gql_limited_actions_policy_enabled": True,
            "interactive_text_enabled": True,
            "responsive_web_text_conversations_enabled": True,
            "longform_notetweets_richtext_consumption_enabled": True,
            "responsive_web_enhance_cards_enabled": True
        }
    },
    "UnmuteList": {
        "queryId": "pMZrHRNsmEkXgbn3tOyr7Q",
        "variables": {},
        "features": {}
    },
    "ListUnpinOne": {
        "queryId": "oVn3dJ4Q1HDvq-UYT8AUdg",
        "variables": {
            "listId": None,
            "withSuperFollowsUserFields": True,
        },
        "features": {
            "responsive_web_twitter_blue_verified_badge_is_enabled": True,
            "responsive_web_graphql_exclude_directive_enabled": True,
            "verified_phone_label_enabled": True,
            "responsive_web_graphql_skip_user_profile_image_extensions_enabled": True,
            "responsive_web_graphql_timeline_navigation_enabled": True
        }
    },
    "ListUnsubscribe": {
        "queryId": "AhfcWLFMXGaFMpzeUYtayA",
        "variables": {},
        "features": {
            "responsive_web_twitter_blue_verified_badge_is_enabled": True,
            "responsive_web_graphql_exclude_directive_enabled": True,
            "verified_phone_label_enabled": True,
            "responsive_web_graphql_skip_user_profile_image_extensions_enabled": True,
            "responsive_web_graphql_timeline_navigation_enabled": True
        }
    },
    "UpdateList": {
        "queryId": "4dCEFWtxEbhnSLcJdJ6PNg",
        "variables": {
            "listId": None,
            "isPrivate": None,  # True/False
            "description": None,
            "name": None,
            "withSuperFollowsUserFields": True,  # True/False
        },
        "features": {
            "responsive_web_twitter_blue_verified_badge_is_enabled": True,
            "responsive_web_graphql_exclude_directive_enabled": True,
            "verified_phone_label_enabled": True,
            "responsive_web_graphql_skip_user_profile_image_extensions_enabled": True,
            "responsive_web_graphql_timeline_navigation_enabled": True
        }
    },
    "ListsDiscovery": {
        "queryId": "MyeubSVb94xuClV0kXSQiw",
        "variables": {},
        "features": {
            "responsive_web_twitter_blue_verified_badge_is_enabled": True,
            "responsive_web_graphql_exclude_directive_enabled": True,
            "verified_phone_label_enabled": True,
            "responsive_web_graphql_timeline_navigation_enabled": True,
            "responsive_web_graphql_skip_user_profile_image_extensions_enabled": True,
            "tweetypie_unmention_optimization_enabled": True,
            "vibe_api_enabled": True,
            "responsive_web_edit_tweet_api_enabled": True,
            "graphql_is_translatable_rweb_tweet_is_translatable_enabled": True,
            "view_counts_everywhere_api_enabled": True,
            "longform_notetweets_consumption_enabled": True,
            "tweet_awards_web_tipping_enabled": True,
            "freedom_of_speech_not_reach_fetch_enabled": True,
            "standardized_nudges_misinfo": True,
            "tweet_with_visibility_results_prefer_gql_limited_actions_policy_enabled": True,
            "interactive_text_enabled": True,
            "responsive_web_text_conversations_enabled": True,
            "longform_notetweets_richtext_consumption_enabled": True,
            "responsive_web_enhance_cards_enabled": True
        }
    },
    "ListsManagementPageTimeline": {
        "queryId": "-xpH2IARz6JqT0nMkHt3KA",
        "variables": {
            "count": 1000,
            "withDownvotePerspective": False,
            "withReactionsMetadata": False,
            "withReactionsPerspective": False,
            "withSuperFollowsTweetFields": False,
            "withSuperFollowsUserFields": False,
        },
        "features": {
            "responsive_web_twitter_blue_verified_badge_is_enabled": True,
            "responsive_web_graphql_exclude_directive_enabled": True,
            "verified_phone_label_enabled": True,
            "responsive_web_graphql_timeline_navigation_enabled": True,
            "responsive_web_graphql_skip_user_profile_image_extensions_enabled": True,
            "tweetypie_unmention_optimization_enabled": True,
            "vibe_api_enabled": True,
            "responsive_web_edit_tweet_api_enabled": True,
            "graphql_is_translatable_rweb_tweet_is_translatable_enabled": True,
            "view_counts_everywhere_api_enabled": True,
            "longform_notetweets_consumption_enabled": True,
            "tweet_awards_web_tipping_enabled": True,
            "freedom_of_speech_not_reach_fetch_enabled": True,
            "standardized_nudges_misinfo": True,
            "tweet_with_visibility_results_prefer_gql_limited_actions_policy_enabled": True,
            "interactive_text_enabled": True,
            "responsive_web_text_conversations_enabled": True,
            "longform_notetweets_richtext_consumption_enabled": True,
            "responsive_web_enhance_cards_enabled": True
        }
    },
    "ListsPinMany": {
        "queryId": "2X4Vqu6XLneR-XZnGK5MAw",
        "variables": {
            "listIds": [],
            "withSuperFollowsUserFields": True,
        },
        "features": {
            "responsive_web_twitter_blue_verified_badge_is_enabled": True,
            "responsive_web_graphql_exclude_directive_enabled": True,
            "verified_phone_label_enabled": True,
            "responsive_web_graphql_skip_user_profile_image_extensions_enabled": True,
            "responsive_web_graphql_timeline_navigation_enabled": True
        }
    },
    "LiveCommerceItemsSlice": {
        "queryId": "-lnNX56S2YrZYrLzbccFAQ",
        "variables": {},
        "features": {}
    },
    "ModerateTweet": {
        "queryId": "pjFnHGVqCjTcZol0xcBJjw",
        "variables": {},
        "features": {}
    },
    "ModeratedTimeline": {
        "queryId": "mhzbOvVnFCa8UG8w2bg7BA",
        "variables": {
            "rootTweetId": None,
            "count": 1000,
            "includePromotedContent": True,
            "withDownvotePerspective": False,
            "withReactionsMetadata": False,
            "withReactionsPerspective": False,
            "withSuperFollowsTweetFields": True,
            "withSuperFollowsUserFields": True
        },
        "features": {
            "responsive_web_twitter_blue_verified_badge_is_enabled": True,
            "responsive_web_graphql_exclude_directive_enabled": True,
            "verified_phone_label_enabled": True,
            "responsive_web_graphql_timeline_navigation_enabled": True,
            "responsive_web_graphql_skip_user_profile_image_extensions_enabled": True,
            "tweetypie_unmention_optimization_enabled": True,
            "vibe_api_enabled": True,
            "responsive_web_edit_tweet_api_enabled": True,
            "graphql_is_translatable_rweb_tweet_is_translatable_enabled": True,
            "view_counts_everywhere_api_enabled": True,
            "longform_notetweets_consumption_enabled": True,
            "tweet_awards_web_tipping_enabled": True,
            "freedom_of_speech_not_reach_fetch_enabled": True,
            "standardized_nudges_misinfo": True,
            "tweet_with_visibility_results_prefer_gql_limited_actions_policy_enabled": True,
            "interactive_text_enabled": True,
            "responsive_web_text_conversations_enabled": True,
            "longform_notetweets_richtext_consumption_enabled": True,
            "responsive_web_enhance_cards_enabled": True
        }
    },
    "MutedAccounts": {
        "queryId": "joFE7-leV60iydenIDnpew",
        "variables": {},
        "features": {
            "responsive_web_twitter_blue_verified_badge_is_enabled": True,
            "responsive_web_graphql_exclude_directive_enabled": True,
            "verified_phone_label_enabled": True,
            "responsive_web_graphql_timeline_navigation_enabled": True,
            "responsive_web_graphql_skip_user_profile_image_extensions_enabled": True,
            "tweetypie_unmention_optimization_enabled": True,
            "vibe_api_enabled": True,
            "responsive_web_edit_tweet_api_enabled": True,
            "graphql_is_translatable_rweb_tweet_is_translatable_enabled": True,
            "view_counts_everywhere_api_enabled": True,
            "longform_notetweets_consumption_enabled": True,
            "tweet_awards_web_tipping_enabled": True,
            "freedom_of_speech_not_reach_fetch_enabled": True,
            "standardized_nudges_misinfo": True,
            "tweet_with_visibility_results_prefer_gql_limited_actions_policy_enabled": True,
            "interactive_text_enabled": True,
            "responsive_web_text_conversations_enabled": True,
            "longform_notetweets_richtext_consumption_enabled": True,
            "responsive_web_enhance_cards_enabled": True
        }
    },
    "NoteworthyAccountsPage": {
        "queryId": "HmxIM_uy0brqVUYXm2OSxA",
        "variables": {},
        "features": {
            "responsive_web_twitter_blue_verified_badge_is_enabled": True,
            "responsive_web_graphql_exclude_directive_enabled": True,
            "verified_phone_label_enabled": True,
            "responsive_web_graphql_timeline_navigation_enabled": True,
            "responsive_web_graphql_skip_user_profile_image_extensions_enabled": True,
            "tweetypie_unmention_optimization_enabled": True,
            "vibe_api_enabled": True,
            "responsive_web_edit_tweet_api_enabled": True,
            "graphql_is_translatable_rweb_tweet_is_translatable_enabled": True,
            "view_counts_everywhere_api_enabled": True,
            "longform_notetweets_consumption_enabled": True,
            "tweet_awards_web_tipping_enabled": True,
            "freedom_of_speech_not_reach_fetch_enabled": True,
            "standardized_nudges_misinfo": True,
            "tweet_with_visibility_results_prefer_gql_limited_actions_policy_enabled": True,
            "interactive_text_enabled": True,
            "responsive_web_text_conversations_enabled": True,
            "longform_notetweets_richtext_consumption_enabled": True,
            "responsive_web_enhance_cards_enabled": True
        }
    },
    "PaymentMethods": {
        "queryId": "mPF_G9okpbZuLcD6mN8K9g",
        "variables": {},
        "features": {}
    },
    "PinReply": {
        "queryId": "GA2_1uKP9b_GyR4MVAQXAw",
        "variables": {},
        "features": {}
    },
    "UnpinReply": {
        "queryId": "iRe6ig5OV1EzOtldNIuGDQ",
        "variables": {},
        "features": {}
    },
    "ProfileUserPhoneState": {
        "queryId": "5kUWP8C1hcd6omvg6HXXTQ",
        "variables": {},
        "features": {}
    },
    "PutClientEducationFlag": {
        "queryId": "IjQ-egg0uPkY11NyPMfRMQ",
        "variables": {},
        "features": {}
    },
    "AdAccounts": {
        "queryId": "a8KxGfFQAmm3WxqemuqSRA",
        "variables": {},
        "features": {}
    },
    "AudienceEstimate": {
        "queryId": "1LYVUabJBYkPlUAWRabB3g",
        "variables": {},
        "features": {}
    },
    "Budgets": {
        "queryId": "mbK3oSQotwcJXyQIBE3uYw",
        "variables": {},
        "features": {}
    },
    "Coupons": {
        "queryId": "R1h43jnAl2bsDoUkgZb7NQ",
        "variables": {},
        "features": {}
    },
    "CreateQuickPromotion": {
        "queryId": "oDSoVgHhJxnd5IkckgPZdg",
        "variables": {},
        "features": {}
    },
    "QuickPromoteEligibility": {
        "queryId": "LtpCXh66W-uXh7u7XSRA8Q",
        "variables": {},
        "features": {}
    },
    "EnrollCoupon": {
        "queryId": "SOyGmNGaEXcvk15s5bqDrA",
        "variables": {},
        "features": {}
    },
    "RemoveFollower": {
        "queryId": "QpNfg0kpPRfjROQ_9eOLXA",
        "variables": {},
        "features": {}
    },
    "RemoveTweetFromBookmarkFolder": {
        "queryId": "2Qbj9XZvtUvyJB4gFwWfaA",
        "variables": {},
        "features": {}
    },
    "Retweeters": {
        "queryId": "0BoJlKAxoNPQUHRftlwZ2w",
        "variables": {
            "tweetId": None,
            "count": 1000,
            "includePromotedContent": True,
            "withSuperFollowsUserFields": True,
            "withDownvotePerspective": False,
            "withReactionsMetadata": False,
            "withReactionsPerspective": False,
            "withSuperFollowsTweetFields": True
        },
        "features": {
            "responsive_web_twitter_blue_verified_badge_is_enabled": True,
            "responsive_web_graphql_exclude_directive_enabled": True,
            "verified_phone_label_enabled": True,
            "responsive_web_graphql_timeline_navigation_enabled": True,
            "responsive_web_graphql_skip_user_profile_image_extensions_enabled": True,
            "tweetypie_unmention_optimization_enabled": True,
            "vibe_api_enabled": True,
            "responsive_web_edit_tweet_api_enabled": True,
            "graphql_is_translatable_rweb_tweet_is_translatable_enabled": True,
            "view_counts_everywhere_api_enabled": True,
            "longform_notetweets_consumption_enabled": True,
            "tweet_awards_web_tipping_enabled": True,
            "freedom_of_speech_not_reach_fetch_enabled": True,
            "standardized_nudges_misinfo": True,
            "tweet_with_visibility_results_prefer_gql_limited_actions_policy_enabled": True,
            "interactive_text_enabled": True,
            "responsive_web_text_conversations_enabled": True,
            "longform_notetweets_richtext_consumption_enabled": True,
            "responsive_web_enhance_cards_enabled": True
        }
    },
    "RitoActionedTweetsTimeline": {
        "queryId": "8iqIOQT0x4SQvgULbu9D_g",
        "variables": {},
        "features": {
            "responsive_web_twitter_blue_verified_badge_is_enabled": True,
            "responsive_web_graphql_exclude_directive_enabled": True,
            "verified_phone_label_enabled": True,
            "responsive_web_graphql_timeline_navigation_enabled": True,
            "responsive_web_graphql_skip_user_profile_image_extensions_enabled": True,
            "tweetypie_unmention_optimization_enabled": True,
            "vibe_api_enabled": True,
            "responsive_web_edit_tweet_api_enabled": True,
            "graphql_is_translatable_rweb_tweet_is_translatable_enabled": True,
            "view_counts_everywhere_api_enabled": True,
            "longform_notetweets_consumption_enabled": True,
            "tweet_awards_web_tipping_enabled": True,
            "freedom_of_speech_not_reach_fetch_enabled": True,
            "standardized_nudges_misinfo": True,
            "tweet_with_visibility_results_prefer_gql_limited_actions_policy_enabled": True,
            "interactive_text_enabled": True,
            "responsive_web_text_conversations_enabled": True,
            "longform_notetweets_richtext_consumption_enabled": True,
            "responsive_web_enhance_cards_enabled": True
        }
    },
    "RitoFlaggedAccountsTimeline": {
        "queryId": "9bnCGPHDI_yk7vJDlToKkw",
        "variables": {},
        "features": {
            "responsive_web_twitter_blue_verified_badge_is_enabled": True,
            "responsive_web_graphql_exclude_directive_enabled": True,
            "verified_phone_label_enabled": True,
            "responsive_web_graphql_timeline_navigation_enabled": True,
            "responsive_web_graphql_skip_user_profile_image_extensions_enabled": True,
            "tweetypie_unmention_optimization_enabled": True,
            "vibe_api_enabled": True,
            "responsive_web_edit_tweet_api_enabled": True,
            "graphql_is_translatable_rweb_tweet_is_translatable_enabled": True,
            "view_counts_everywhere_api_enabled": True,
            "longform_notetweets_consumption_enabled": True,
            "tweet_awards_web_tipping_enabled": True,
            "freedom_of_speech_not_reach_fetch_enabled": True,
            "standardized_nudges_misinfo": True,
            "tweet_with_visibility_results_prefer_gql_limited_actions_policy_enabled": True,
            "interactive_text_enabled": True,
            "responsive_web_text_conversations_enabled": True,
            "longform_notetweets_richtext_consumption_enabled": True,
            "responsive_web_enhance_cards_enabled": True
        }
    },
    "RitoFlaggedTweetsTimeline": {
        "queryId": "_XNqSModnKoclHMD6oDmNw",
        "variables": {},
        "features": {
            "responsive_web_twitter_blue_verified_badge_is_enabled": True,
            "responsive_web_graphql_exclude_directive_enabled": True,
            "verified_phone_label_enabled": True,
            "responsive_web_graphql_timeline_navigation_enabled": True,
            "responsive_web_graphql_skip_user_profile_image_extensions_enabled": True,
            "tweetypie_unmention_optimization_enabled": True,
            "vibe_api_enabled": True,
            "responsive_web_edit_tweet_api_enabled": True,
            "graphql_is_translatable_rweb_tweet_is_translatable_enabled": True,
            "view_counts_everywhere_api_enabled": True,
            "longform_notetweets_consumption_enabled": True,
            "tweet_awards_web_tipping_enabled": True,
            "freedom_of_speech_not_reach_fetch_enabled": True,
            "standardized_nudges_misinfo": True,
            "tweet_with_visibility_results_prefer_gql_limited_actions_policy_enabled": True,
            "interactive_text_enabled": True,
            "responsive_web_text_conversations_enabled": True,
            "longform_notetweets_richtext_consumption_enabled": True,
            "responsive_web_enhance_cards_enabled": True
        }
    },
    "RitoSuggestedActionsFacePile": {
        "queryId": "GnQKeEdL1LyeK3dTQCS1yw",
        "variables": {},
        "features": {}
    },
    "GetSafetyModeSettings": {
        "queryId": "AhxTX0lkbIos4WG53xwzSA",
        "variables": {},
        "features": {}
    },
    "SetSafetyModeSettings": {
        "queryId": "qSJIPIpf4gA7Wn21bT3D4w",
        "variables": {},
        "features": {}
    },
    "FetchScheduledTweets": {
        "queryId": "ITtjAzvlZni2wWXwf295Qg",
        "variables": {
            "ascending": True
        },
        "features": {}
    },
    "SharingAudiospacesListeningDataWithFollowersUpdate": {
        "queryId": "5h0kNbk3ii97rmfY6CdgAA",
        "variables": {},
        "features": {}
    },
    "SubscribeToScheduledSpace": {
        "queryId": "Sxn4YOlaAwEKjnjWV0h7Mw",
        "variables": {},
        "features": {}
    },
    "SubscriptionCheckoutUrlWithEligibility": {
        "queryId": "hKfOOObQr5JmfmxW0YtPvg",
        "variables": {},
        "features": {}
    },
    "SubscriptionProductDetails": {
        "queryId": "GZF6Vha91bWrZjDmZZ-VNA",
        "variables": {},
        "features": {}
    },
    "SubscriptionProductFeaturesFetch": {
        "queryId": "Me2CVcAXxvK2WMr-Nh_Qqg",
        "variables": {},
        "features": {}
    },
    "SuperFollowers": {
        "queryId": "BQIYNSwMPfKmT-fqGbxkaA",
        "variables": {},
        "features": {
            "responsive_web_twitter_blue_verified_badge_is_enabled": True,
            "responsive_web_graphql_exclude_directive_enabled": True,
            "verified_phone_label_enabled": True,
            "responsive_web_graphql_timeline_navigation_enabled": True,
            "responsive_web_graphql_skip_user_profile_image_extensions_enabled": True,
            "tweetypie_unmention_optimization_enabled": True,
            "vibe_api_enabled": True,
            "responsive_web_edit_tweet_api_enabled": True,
            "graphql_is_translatable_rweb_tweet_is_translatable_enabled": True,
            "view_counts_everywhere_api_enabled": True,
            "longform_notetweets_consumption_enabled": True,
            "tweet_awards_web_tipping_enabled": True,
            "freedom_of_speech_not_reach_fetch_enabled": True,
            "standardized_nudges_misinfo": True,
            "tweet_with_visibility_results_prefer_gql_limited_actions_policy_enabled": True,
            "interactive_text_enabled": True,
            "responsive_web_text_conversations_enabled": True,
            "longform_notetweets_richtext_consumption_enabled": True,
            "responsive_web_enhance_cards_enabled": True
        }
    },
    "timelinesFeedback": {
        "queryId": "vfVbgvTPTQ-dF_PQ5lD1WQ",
        "variables": {},
        "features": {}
    },
    "TopicFollow": {
        "queryId": "ElqSLWFmsPL4NlZI5e1Grg",
        "variables": {
            "topicId": None
        },
        "features": {}
    },
    "TopicLandingPage": {
        "queryId": "QqvCpKOp5tbk09ZQ4Ay-IQ",
        "variables": {},
        "features": {
            "responsive_web_twitter_blue_verified_badge_is_enabled": True,
            "responsive_web_graphql_exclude_directive_enabled": True,
            "verified_phone_label_enabled": True,
            "responsive_web_graphql_timeline_navigation_enabled": True,
            "responsive_web_graphql_skip_user_profile_image_extensions_enabled": True,
            "tweetypie_unmention_optimization_enabled": True,
            "vibe_api_enabled": True,
            "responsive_web_edit_tweet_api_enabled": True,
            "graphql_is_translatable_rweb_tweet_is_translatable_enabled": True,
            "view_counts_everywhere_api_enabled": True,
            "longform_notetweets_consumption_enabled": True,
            "tweet_awards_web_tipping_enabled": True,
            "freedom_of_speech_not_reach_fetch_enabled": True,
            "standardized_nudges_misinfo": True,
            "tweet_with_visibility_results_prefer_gql_limited_actions_policy_enabled": True,
            "interactive_text_enabled": True,
            "responsive_web_text_conversations_enabled": True,
            "longform_notetweets_richtext_consumption_enabled": True,
            "responsive_web_enhance_cards_enabled": True
        }
    },
    "TopicNotInterested": {
        "queryId": "cPCFdDAaqRjlMRYInZzoDA",
        "variables": {},
        "features": {}
    },
    "TopicByRestId": {
        "queryId": "4OUZZOonV2h60I0wdlQb_w",
        "variables": {},
        "features": {}
    },
    "TopicToFollowSidebar": {
        "queryId": "O-tnGnESFUk_Y7HvI6QvAQ",
        "variables": {},
        "features": {
            "responsive_web_twitter_blue_verified_badge_is_enabled": True,
            "responsive_web_graphql_exclude_directive_enabled": True,
            "verified_phone_label_enabled": True,
            "responsive_web_graphql_timeline_navigation_enabled": True,
            "responsive_web_graphql_skip_user_profile_image_extensions_enabled": True,
            "tweetypie_unmention_optimization_enabled": True,
            "vibe_api_enabled": True,
            "responsive_web_edit_tweet_api_enabled": True,
            "graphql_is_translatable_rweb_tweet_is_translatable_enabled": True,
            "view_counts_everywhere_api_enabled": True,
            "longform_notetweets_consumption_enabled": True,
            "tweet_awards_web_tipping_enabled": True,
            "freedom_of_speech_not_reach_fetch_enabled": True,
            "standardized_nudges_misinfo": True,
            "tweet_with_visibility_results_prefer_gql_limited_actions_policy_enabled": True,
            "interactive_text_enabled": True,
            "responsive_web_text_conversations_enabled": True,
            "longform_notetweets_richtext_consumption_enabled": True,
            "responsive_web_enhance_cards_enabled": True
        }
    },
    "TopicUndoNotInterested": {
        "queryId": "4tVnt6FoSxaX8L-mDDJo4Q",
        "variables": {},
        "features": {}
    },
    "TopicUnfollow": {
        "queryId": "srwjU6JM_ZKTj_QMfUGNcw",
        "variables": {
            "topicId": None
        },
        "features": {}
    },
    "TopicsManagementPage": {
        "queryId": "wCDJjeosMB7Hk7_fzjJzhg",
        "variables": {},
        "features": {
            "responsive_web_twitter_blue_verified_badge_is_enabled": True,
            "responsive_web_graphql_exclude_directive_enabled": True,
            "verified_phone_label_enabled": True,
            "responsive_web_graphql_timeline_navigation_enabled": True,
            "responsive_web_graphql_skip_user_profile_image_extensions_enabled": True,
            "tweetypie_unmention_optimization_enabled": True,
            "vibe_api_enabled": True,
            "responsive_web_edit_tweet_api_enabled": True,
            "graphql_is_translatable_rweb_tweet_is_translatable_enabled": True,
            "view_counts_everywhere_api_enabled": True,
            "longform_notetweets_consumption_enabled": True,
            "tweet_awards_web_tipping_enabled": True,
            "freedom_of_speech_not_reach_fetch_enabled": True,
            "standardized_nudges_misinfo": True,
            "tweet_with_visibility_results_prefer_gql_limited_actions_policy_enabled": True,
            "interactive_text_enabled": True,
            "responsive_web_text_conversations_enabled": True,
            "longform_notetweets_richtext_consumption_enabled": True,
            "responsive_web_enhance_cards_enabled": True
        }
    },
    "TopicsPickerPage": {
        "queryId": "TOu480G65VAXfGLnJiqdng",
        "variables": {},
        "features": {
            "responsive_web_twitter_blue_verified_badge_is_enabled": True,
            "responsive_web_graphql_exclude_directive_enabled": True,
            "verified_phone_label_enabled": True,
            "responsive_web_graphql_timeline_navigation_enabled": True,
            "responsive_web_graphql_skip_user_profile_image_extensions_enabled": True,
            "tweetypie_unmention_optimization_enabled": True,
            "vibe_api_enabled": True,
            "responsive_web_edit_tweet_api_enabled": True,
            "graphql_is_translatable_rweb_tweet_is_translatable_enabled": True,
            "view_counts_everywhere_api_enabled": True,
            "longform_notetweets_consumption_enabled": True,
            "tweet_awards_web_tipping_enabled": True,
            "freedom_of_speech_not_reach_fetch_enabled": True,
            "standardized_nudges_misinfo": True,
            "tweet_with_visibility_results_prefer_gql_limited_actions_policy_enabled": True,
            "interactive_text_enabled": True,
            "responsive_web_text_conversations_enabled": True,
            "longform_notetweets_richtext_consumption_enabled": True,
            "responsive_web_enhance_cards_enabled": True
        }
    },
    "TopicsPickerPageById": {
        "queryId": "K_M3YAag4oBcqIaUyy9eUA",
        "variables": {},
        "features": {
            "responsive_web_twitter_blue_verified_badge_is_enabled": True,
            "responsive_web_graphql_exclude_directive_enabled": True,
            "verified_phone_label_enabled": True,
            "responsive_web_graphql_timeline_navigation_enabled": True,
            "responsive_web_graphql_skip_user_profile_image_extensions_enabled": True,
            "tweetypie_unmention_optimization_enabled": True,
            "vibe_api_enabled": True,
            "responsive_web_edit_tweet_api_enabled": True,
            "graphql_is_translatable_rweb_tweet_is_translatable_enabled": True,
            "view_counts_everywhere_api_enabled": True,
            "longform_notetweets_consumption_enabled": True,
            "tweet_awards_web_tipping_enabled": True,
            "freedom_of_speech_not_reach_fetch_enabled": True,
            "standardized_nudges_misinfo": True,
            "tweet_with_visibility_results_prefer_gql_limited_actions_policy_enabled": True,
            "interactive_text_enabled": True,
            "responsive_web_text_conversations_enabled": True,
            "longform_notetweets_richtext_consumption_enabled": True,
            "responsive_web_enhance_cards_enabled": True
        }
    },
    "TrustedFriendsTypeahead": {
        "queryId": "_vUIWq3vpyL0amiNTjrM-w",
        "variables": {},
        "features": {
            "responsive_web_twitter_blue_verified_badge_is_enabled": True,
            "responsive_web_graphql_timeline_navigation_enabled": True
        }
    },
    "TweetDetail": {
        "queryId": "zXaXQgfyR4GxE21uwYQSyA",
        "variables": {
            "focalTweetId": None,
            "with_rux_injections": False,
            "includePromotedContent": True,
            "withCommunity": True,
            "withQuickPromoteEligibilityTweetFields": True,
            "withBirdwatchNotes": True,
            "withSuperFollowsUserFields": True,
            "withDownvotePerspective": False,
            "withReactionsMetadata": False,
            "withReactionsPerspective": False,
            "withSuperFollowsTweetFields": True,
            "withVoice": True,
            "withV2Timeline": True
        },
        "features": {
            "responsive_web_twitter_blue_verified_badge_is_enabled": True,
            "responsive_web_graphql_exclude_directive_enabled": True,
            "verified_phone_label_enabled": True,
            "responsive_web_graphql_timeline_navigation_enabled": True,
            "responsive_web_graphql_skip_user_profile_image_extensions_enabled": True,
            "tweetypie_unmention_optimization_enabled": True,
            "vibe_api_enabled": True,
            "responsive_web_edit_tweet_api_enabled": True,
            "graphql_is_translatable_rweb_tweet_is_translatable_enabled": True,
            "view_counts_everywhere_api_enabled": True,
            "longform_notetweets_consumption_enabled": True,
            "tweet_awards_web_tipping_enabled": True,
            "freedom_of_speech_not_reach_fetch_enabled": True,
            "standardized_nudges_misinfo": True,
            "tweet_with_visibility_results_prefer_gql_limited_actions_policy_enabled": True,
            "interactive_text_enabled": True,
            "responsive_web_text_conversations_enabled": True,
            "longform_notetweets_richtext_consumption_enabled": True,
            "responsive_web_enhance_cards_enabled": True
        }
    },
    "TweetEditHistory": {
        "queryId": "coQ70Jlk_NSi3lB3OFdmCQ",
        "variables": {},
        "features": {
            "freedom_of_speech_not_reach_fetch_enabled": True,
            "standardized_nudges_misinfo": True,
            "tweet_with_visibility_results_prefer_gql_limited_actions_policy_enabled": True,
            "tweetypie_unmention_optimization_enabled": True,
            "vibe_api_enabled": True,
            "responsive_web_edit_tweet_api_enabled": True,
            "graphql_is_translatable_rweb_tweet_is_translatable_enabled": True,
            "view_counts_everywhere_api_enabled": True,
            "longform_notetweets_consumption_enabled": True,
            "tweet_awards_web_tipping_enabled": True,
            "interactive_text_enabled": True,
            "responsive_web_text_conversations_enabled": True,
            "longform_notetweets_richtext_consumption_enabled": True,
            "responsive_web_twitter_blue_verified_badge_is_enabled": True,
            "responsive_web_graphql_exclude_directive_enabled": True,
            "verified_phone_label_enabled": True,
            "responsive_web_graphql_timeline_navigation_enabled": True,
            "responsive_web_graphql_skip_user_profile_image_extensions_enabled": True,
            "responsive_web_enhance_cards_enabled": True
        }
    },
    "GetTweetReactionTimeline": {
        "queryId": "ihIcULrtrtPGlCuprduRrA",
        "variables": {},
        "features": {
            "responsive_web_twitter_blue_verified_badge_is_enabled": True,
            "responsive_web_graphql_exclude_directive_enabled": True,
            "verified_phone_label_enabled": True,
            "responsive_web_graphql_skip_user_profile_image_extensions_enabled": True,
            "responsive_web_graphql_timeline_navigation_enabled": True
        }
    },
    "TweetResultByRestId": {
        "queryId": "D_jNhjWZeRZT5NURzfJZSQ",
        "variables": {
            "tweetId": None,
            "includePromotedContent": True,
            "withBirdwatchNotes": True,
            "withVoice": True,
            "withCommunity": True,
            "withSuperFollowsUserFields": True,
            "withDownvotePerspective": False,
            "withReactionsMetadata": False,
            "withReactionsPerspective": False,
            "withSuperFollowsTweetFields": True
        },
        "features": {
            "tweetypie_unmention_optimization_enabled": True,
            "vibe_api_enabled": True,
            "responsive_web_edit_tweet_api_enabled": True,
            "graphql_is_translatable_rweb_tweet_is_translatable_enabled": True,
            "view_counts_everywhere_api_enabled": True,
            "longform_notetweets_consumption_enabled": True,
            "tweet_awards_web_tipping_enabled": True,
            "freedom_of_speech_not_reach_fetch_enabled": True,
            "standardized_nudges_misinfo": True,
            "tweet_with_visibility_results_prefer_gql_limited_actions_policy_enabled": True,
            "interactive_text_enabled": True,
            "responsive_web_text_conversations_enabled": True,
            "longform_notetweets_richtext_consumption_enabled": True,
            "responsive_web_twitter_blue_verified_badge_is_enabled": True,
            "responsive_web_graphql_exclude_directive_enabled": True,
            "verified_phone_label_enabled": True,
            "responsive_web_graphql_timeline_navigation_enabled": True,
            "responsive_web_graphql_skip_user_profile_image_extensions_enabled": True,
            "responsive_web_enhance_cards_enabled": True
        }
    },
    "TweetStats": {
        "queryId": "EvbTkPDT-xQCfupPu0rWMA",
        "variables": {
            "rest_id": None
        },
        "features": {
            "profile_foundations_tweet_stats_enabled": True,
            "profile_foundations_tweet_stats_tweet_frequency": True
        }
    },
    "TwitterArticleCreate": {
        "queryId": "sGXhodE6Dltxhlbialo5iA",
        "variables": {},
        "features": {
            "responsive_web_twitter_article_data_v2_enabled": True,
            "responsive_web_twitter_blue_verified_badge_is_enabled": True,
            "responsive_web_graphql_exclude_directive_enabled": True,
            "verified_phone_label_enabled": True,
            "responsive_web_graphql_skip_user_profile_image_extensions_enabled": True,
            "responsive_web_graphql_timeline_navigation_enabled": True,
            "tweetypie_unmention_optimization_enabled": True,
            "vibe_api_enabled": True,
            "responsive_web_edit_tweet_api_enabled": True,
            "graphql_is_translatable_rweb_tweet_is_translatable_enabled": True,
            "view_counts_everywhere_api_enabled": True,
            "longform_notetweets_consumption_enabled": True,
            "tweet_awards_web_tipping_enabled": True,
            "freedom_of_speech_not_reach_fetch_enabled": True,
            "standardized_nudges_misinfo": True,
            "tweet_with_visibility_results_prefer_gql_limited_actions_policy_enabled": True,
            "interactive_text_enabled": True,
            "responsive_web_text_conversations_enabled": True,
            "longform_notetweets_richtext_consumption_enabled": True,
            "responsive_web_enhance_cards_enabled": True
        }
    },
    "TwitterArticleDelete": {
        "queryId": "6st-stMDc7KBqLT8KvWhHg",
        "variables": {},
        "features": {}
    },
    "TwitterArticleByRestId": {
        "queryId": "mVoL1eoSf2OlGuBGpkryfg",
        "variables": {},
        "features": {
            "responsive_web_twitter_article_data_v2_enabled": True,
            "responsive_web_twitter_blue_verified_badge_is_enabled": True,
            "responsive_web_graphql_exclude_directive_enabled": True,
            "verified_phone_label_enabled": True,
            "responsive_web_graphql_skip_user_profile_image_extensions_enabled": True,
            "responsive_web_graphql_timeline_navigation_enabled": True,
            "tweetypie_unmention_optimization_enabled": True,
            "vibe_api_enabled": True,
            "responsive_web_edit_tweet_api_enabled": True,
            "graphql_is_translatable_rweb_tweet_is_translatable_enabled": True,
            "view_counts_everywhere_api_enabled": True,
            "longform_notetweets_consumption_enabled": True,
            "tweet_awards_web_tipping_enabled": True,
            "freedom_of_speech_not_reach_fetch_enabled": True,
            "standardized_nudges_misinfo": True,
            "tweet_with_visibility_results_prefer_gql_limited_actions_policy_enabled": True,
            "interactive_text_enabled": True,
            "responsive_web_text_conversations_enabled": True,
            "longform_notetweets_richtext_consumption_enabled": True,
            "responsive_web_enhance_cards_enabled": True
        }
    },
    "TwitterArticleUpdateCoverImage": {
        "queryId": "0mp-rT_Rx_cG6U8W3k-fRQ",
        "variables": {},
        "features": {
            "responsive_web_twitter_article_data_v2_enabled": True,
            "responsive_web_twitter_blue_verified_badge_is_enabled": True,
            "responsive_web_graphql_exclude_directive_enabled": True,
            "verified_phone_label_enabled": True,
            "responsive_web_graphql_skip_user_profile_image_extensions_enabled": True,
            "responsive_web_graphql_timeline_navigation_enabled": True,
            "tweetypie_unmention_optimization_enabled": True,
            "vibe_api_enabled": True,
            "responsive_web_edit_tweet_api_enabled": True,
            "graphql_is_translatable_rweb_tweet_is_translatable_enabled": True,
            "view_counts_everywhere_api_enabled": True,
            "longform_notetweets_consumption_enabled": True,
            "tweet_awards_web_tipping_enabled": True,
            "freedom_of_speech_not_reach_fetch_enabled": True,
            "standardized_nudges_misinfo": True,
            "tweet_with_visibility_results_prefer_gql_limited_actions_policy_enabled": True,
            "interactive_text_enabled": True,
            "responsive_web_text_conversations_enabled": True,
            "longform_notetweets_richtext_consumption_enabled": True,
            "responsive_web_enhance_cards_enabled": True
        }
    },
    "TwitterArticleUpdateData": {
        "queryId": "r__zSVe8KW9qbUYX_-uLFQ",
        "variables": {},
        "features": {
            "responsive_web_twitter_article_data_v2_enabled": True,
            "responsive_web_twitter_blue_verified_badge_is_enabled": True,
            "responsive_web_graphql_exclude_directive_enabled": True,
            "verified_phone_label_enabled": True,
            "responsive_web_graphql_skip_user_profile_image_extensions_enabled": True,
            "responsive_web_graphql_timeline_navigation_enabled": True,
            "tweetypie_unmention_optimization_enabled": True,
            "vibe_api_enabled": True,
            "responsive_web_edit_tweet_api_enabled": True,
            "graphql_is_translatable_rweb_tweet_is_translatable_enabled": True,
            "view_counts_everywhere_api_enabled": True,
            "longform_notetweets_consumption_enabled": True,
            "tweet_awards_web_tipping_enabled": True,
            "freedom_of_speech_not_reach_fetch_enabled": True,
            "standardized_nudges_misinfo": True,
            "tweet_with_visibility_results_prefer_gql_limited_actions_policy_enabled": True,
            "interactive_text_enabled": True,
            "responsive_web_text_conversations_enabled": True,
            "longform_notetweets_richtext_consumption_enabled": True,
            "responsive_web_enhance_cards_enabled": True
        }
    },
    "TwitterArticleUpdateMedia": {
        "queryId": "YI_ZepiIMqNNt4p5RLDTQw",
        "variables": {},
        "features": {
            "responsive_web_twitter_article_data_v2_enabled": True,
            "responsive_web_twitter_blue_verified_badge_is_enabled": True,
            "responsive_web_graphql_exclude_directive_enabled": True,
            "verified_phone_label_enabled": True,
            "responsive_web_graphql_skip_user_profile_image_extensions_enabled": True,
            "responsive_web_graphql_timeline_navigation_enabled": True,
            "tweetypie_unmention_optimization_enabled": True,
            "vibe_api_enabled": True,
            "responsive_web_edit_tweet_api_enabled": True,
            "graphql_is_translatable_rweb_tweet_is_translatable_enabled": True,
            "view_counts_everywhere_api_enabled": True,
            "longform_notetweets_consumption_enabled": True,
            "tweet_awards_web_tipping_enabled": True,
            "freedom_of_speech_not_reach_fetch_enabled": True,
            "standardized_nudges_misinfo": True,
            "tweet_with_visibility_results_prefer_gql_limited_actions_policy_enabled": True,
            "interactive_text_enabled": True,
            "responsive_web_text_conversations_enabled": True,
            "longform_notetweets_richtext_consumption_enabled": True,
            "responsive_web_enhance_cards_enabled": True
        }
    },
    "TwitterArticleUpdateTitle": {
        "queryId": "6ovmzBFIwaFx01qSCOcbgQ",
        "variables": {},
        "features": {
            "responsive_web_twitter_article_data_v2_enabled": True,
            "responsive_web_twitter_blue_verified_badge_is_enabled": True,
            "responsive_web_graphql_exclude_directive_enabled": True,
            "verified_phone_label_enabled": True,
            "responsive_web_graphql_skip_user_profile_image_extensions_enabled": True,
            "responsive_web_graphql_timeline_navigation_enabled": True,
            "tweetypie_unmention_optimization_enabled": True,
            "vibe_api_enabled": True,
            "responsive_web_edit_tweet_api_enabled": True,
            "graphql_is_translatable_rweb_tweet_is_translatable_enabled": True,
            "view_counts_everywhere_api_enabled": True,
            "longform_notetweets_consumption_enabled": True,
            "tweet_awards_web_tipping_enabled": True,
            "freedom_of_speech_not_reach_fetch_enabled": True,
            "standardized_nudges_misinfo": True,
            "tweet_with_visibility_results_prefer_gql_limited_actions_policy_enabled": True,
            "interactive_text_enabled": True,
            "responsive_web_text_conversations_enabled": True,
            "longform_notetweets_richtext_consumption_enabled": True,
            "responsive_web_enhance_cards_enabled": True
        }
    },
    "TwitterArticleUpdateVisibility": {
        "queryId": "Hm_3BGv0gAkSsZUIIbcoeA",
        "variables": {},
        "features": {
            "responsive_web_twitter_article_data_v2_enabled": True,
            "responsive_web_twitter_blue_verified_badge_is_enabled": True,
            "responsive_web_graphql_exclude_directive_enabled": True,
            "verified_phone_label_enabled": True,
            "responsive_web_graphql_skip_user_profile_image_extensions_enabled": True,
            "responsive_web_graphql_timeline_navigation_enabled": True,
            "tweetypie_unmention_optimization_enabled": True,
            "vibe_api_enabled": True,
            "responsive_web_edit_tweet_api_enabled": True,
            "graphql_is_translatable_rweb_tweet_is_translatable_enabled": True,
            "view_counts_everywhere_api_enabled": True,
            "longform_notetweets_consumption_enabled": True,
            "tweet_awards_web_tipping_enabled": True,
            "freedom_of_speech_not_reach_fetch_enabled": True,
            "standardized_nudges_misinfo": True,
            "tweet_with_visibility_results_prefer_gql_limited_actions_policy_enabled": True,
            "interactive_text_enabled": True,
            "responsive_web_text_conversations_enabled": True,
            "longform_notetweets_richtext_consumption_enabled": True,
            "responsive_web_enhance_cards_enabled": True
        }
    },
    "TwitterArticlesSlice": {
        "queryId": "AmzI_uIjc7u7tqqEqnVCcw",
        "variables": {},
        "features": {
            "responsive_web_twitter_article_data_v2_enabled": True,
            "responsive_web_twitter_blue_verified_badge_is_enabled": True,
            "responsive_web_graphql_exclude_directive_enabled": True,
            "verified_phone_label_enabled": True,
            "responsive_web_graphql_skip_user_profile_image_extensions_enabled": True,
            "responsive_web_graphql_timeline_navigation_enabled": True,
            "tweetypie_unmention_optimization_enabled": True,
            "vibe_api_enabled": True,
            "responsive_web_edit_tweet_api_enabled": True,
            "graphql_is_translatable_rweb_tweet_is_translatable_enabled": True,
            "view_counts_everywhere_api_enabled": True,
            "longform_notetweets_consumption_enabled": True,
            "tweet_awards_web_tipping_enabled": True,
            "freedom_of_speech_not_reach_fetch_enabled": True,
            "standardized_nudges_misinfo": True,
            "tweet_with_visibility_results_prefer_gql_limited_actions_policy_enabled": True,
            "interactive_text_enabled": True,
            "responsive_web_text_conversations_enabled": True,
            "longform_notetweets_richtext_consumption_enabled": True,
            "responsive_web_enhance_cards_enabled": True
        }
    },
    "UnfavoriteTweet": {
        "queryId": "ZYKSe-w7KEslx3JhSIk5LA",
        "variables": {
            "tweet_id": None
        },
        "features": {}
    },
    "UnmentionUserFromConversation": {
        "queryId": "xVW9j3OqoBRY9d6_2OONEg",
        "variables": {},
        "features": {}
    },
    "UnmoderateTweet": {
        "queryId": "pVSyu6PA57TLvIE4nN2tsA",
        "variables": {},
        "features": {}
    },
    "UnsubscribeFromScheduledSpace": {
        "queryId": "Zevhh76Msw574ZSs2NQHGQ",
        "variables": {},
        "features": {}
    },
    "UrtFixtures": {
        "queryId": "FZSojQVZVb-r7NWAk1tU1w",
        "variables": {},
        "features": {
            "responsive_web_twitter_blue_verified_badge_is_enabled": True,
            "responsive_web_graphql_exclude_directive_enabled": True,
            "verified_phone_label_enabled": True,
            "responsive_web_graphql_timeline_navigation_enabled": True,
            "responsive_web_graphql_skip_user_profile_image_extensions_enabled": True,
            "tweetypie_unmention_optimization_enabled": True,
            "vibe_api_enabled": True,
            "responsive_web_edit_tweet_api_enabled": True,
            "graphql_is_translatable_rweb_tweet_is_translatable_enabled": True,
            "view_counts_everywhere_api_enabled": True,
            "longform_notetweets_consumption_enabled": True,
            "tweet_awards_web_tipping_enabled": True,
            "freedom_of_speech_not_reach_fetch_enabled": True,
            "standardized_nudges_misinfo": True,
            "tweet_with_visibility_results_prefer_gql_limited_actions_policy_enabled": True,
            "interactive_text_enabled": True,
            "responsive_web_text_conversations_enabled": True,
            "longform_notetweets_richtext_consumption_enabled": True,
            "responsive_web_enhance_cards_enabled": True
        }
    },
    "UserAboutTimeline": {
        "queryId": "Oica4bXjJsZIr09aEl6BaQ",
        "variables": {},
        "features": {
            "responsive_web_twitter_blue_verified_badge_is_enabled": True,
            "responsive_web_graphql_exclude_directive_enabled": True,
            "verified_phone_label_enabled": True,
            "responsive_web_graphql_timeline_navigation_enabled": True,
            "responsive_web_graphql_skip_user_profile_image_extensions_enabled": True,
            "tweetypie_unmention_optimization_enabled": True,
            "vibe_api_enabled": True,
            "responsive_web_edit_tweet_api_enabled": True,
            "graphql_is_translatable_rweb_tweet_is_translatable_enabled": True,
            "view_counts_everywhere_api_enabled": True,
            "longform_notetweets_consumption_enabled": True,
            "tweet_awards_web_tipping_enabled": True,
            "freedom_of_speech_not_reach_fetch_enabled": True,
            "standardized_nudges_misinfo": True,
            "tweet_with_visibility_results_prefer_gql_limited_actions_policy_enabled": True,
            "interactive_text_enabled": True,
            "responsive_web_text_conversations_enabled": True,
            "longform_notetweets_richtext_consumption_enabled": True,
            "responsive_web_enhance_cards_enabled": True
        }
    },
    "UserAccountLabel": {
        "queryId": "rD5gLxVmMvtdtYU1UHWlFQ",
        "variables": {},
        "features": {}
    },
    "UserBusinessProfileTeamTimeline": {
        "queryId": "o6dy2QT9-gZTpi-j45r1kA",
        "variables": {},
        "features": {
            "responsive_web_twitter_blue_verified_badge_is_enabled": True,
            "responsive_web_graphql_exclude_directive_enabled": True,
            "verified_phone_label_enabled": True,
            "responsive_web_graphql_timeline_navigation_enabled": True,
            "responsive_web_graphql_skip_user_profile_image_extensions_enabled": True,
            "tweetypie_unmention_optimization_enabled": True,
            "vibe_api_enabled": True,
            "responsive_web_edit_tweet_api_enabled": True,
            "graphql_is_translatable_rweb_tweet_is_translatable_enabled": True,
            "view_counts_everywhere_api_enabled": True,
            "longform_notetweets_consumption_enabled": True,
            "tweet_awards_web_tipping_enabled": True,
            "freedom_of_speech_not_reach_fetch_enabled": True,
            "standardized_nudges_misinfo": True,
            "tweet_with_visibility_results_prefer_gql_limited_actions_policy_enabled": True,
            "interactive_text_enabled": True,
            "responsive_web_text_conversations_enabled": True,
            "longform_notetweets_richtext_consumption_enabled": True,
            "responsive_web_enhance_cards_enabled": True
        }
    },
    "UserByRestId": {
        "queryId": "gUIQEk2xDGzQTX8Ii0Yesw",
        "variables": {
            "userId": None,
            "withSafetyModeUserFields": True,
            "withSuperFollowsUserFields": True
        },
        "features": {
            "responsive_web_twitter_blue_verified_badge_is_enabled": True,
            "responsive_web_graphql_exclude_directive_enabled": True,
            "verified_phone_label_enabled": True,
            "responsive_web_graphql_skip_user_profile_image_extensions_enabled": True,
            "responsive_web_graphql_timeline_navigation_enabled": True
        }
    },
    "UserByScreenName": {
        "queryId": "rePnxwe9LZ51nQ7Sn_xN_A",
        "variables": {
            "screen_name": None,
            "withSafetyModeUserFields": True,
            "withSuperFollowsUserFields": True
        },
        "features": {
            "responsive_web_twitter_blue_verified_badge_is_enabled": True,
            "responsive_web_graphql_exclude_directive_enabled": True,
            "verified_phone_label_enabled": True,
            "responsive_web_graphql_skip_user_profile_image_extensions_enabled": True,
            "responsive_web_graphql_timeline_navigation_enabled": True
        }
    },
    "GetUserClaims": {
        "queryId": "lFi3xnx0auUUnyG4YwpCNw",
        "variables": {},
        "features": {}
    },
    "UserMedia": {
        "queryId": "YcKL-v9RI2t42QCEDfv-9g",
        "variables": {
            "userId": None,
            "count": 1000,
            "includePromotedContent": False,
            "withSuperFollowsUserFields": True,
            "withDownvotePerspective": False,
            "withReactionsMetadata": False,
            "withReactionsPerspective": False,
            "withSuperFollowsTweetFields": True,
            "withClientEventToken": False,
            "withBirdwatchNotes": False,
            "withVoice": True,
            "withV2Timeline": True
        },
        "features": {
            "responsive_web_twitter_blue_verified_badge_is_enabled": True,
            "responsive_web_graphql_exclude_directive_enabled": True,
            "verified_phone_label_enabled": True,
            "responsive_web_graphql_timeline_navigation_enabled": True,
            "responsive_web_graphql_skip_user_profile_image_extensions_enabled": True,
            "tweetypie_unmention_optimization_enabled": True,
            "vibe_api_enabled": True,
            "responsive_web_edit_tweet_api_enabled": True,
            "graphql_is_translatable_rweb_tweet_is_translatable_enabled": True,
            "view_counts_everywhere_api_enabled": True,
            "longform_notetweets_consumption_enabled": True,
            "tweet_awards_web_tipping_enabled": True,
            "freedom_of_speech_not_reach_fetch_enabled": True,
            "standardized_nudges_misinfo": True,
            "tweet_with_visibility_results_prefer_gql_limited_actions_policy_enabled": True,
            "interactive_text_enabled": True,
            "responsive_web_text_conversations_enabled": True,
            "longform_notetweets_richtext_consumption_enabled": True,
            "responsive_web_enhance_cards_enabled": True
        }
    },
    "UserPromotableTweets": {
        "queryId": "Gk8GbzTt57LhitFR_zGhLA",
        "variables": {},
        "features": {
            "responsive_web_twitter_blue_verified_badge_is_enabled": True,
            "responsive_web_graphql_exclude_directive_enabled": True,
            "verified_phone_label_enabled": True,
            "responsive_web_graphql_timeline_navigation_enabled": True,
            "responsive_web_graphql_skip_user_profile_image_extensions_enabled": True,
            "tweetypie_unmention_optimization_enabled": True,
            "vibe_api_enabled": True,
            "responsive_web_edit_tweet_api_enabled": True,
            "graphql_is_translatable_rweb_tweet_is_translatable_enabled": True,
            "view_counts_everywhere_api_enabled": True,
            "longform_notetweets_consumption_enabled": True,
            "tweet_awards_web_tipping_enabled": True,
            "freedom_of_speech_not_reach_fetch_enabled": True,
            "standardized_nudges_misinfo": True,
            "tweet_with_visibility_results_prefer_gql_limited_actions_policy_enabled": True,
            "interactive_text_enabled": True,
            "responsive_web_text_conversations_enabled": True,
            "longform_notetweets_richtext_consumption_enabled": True,
            "responsive_web_enhance_cards_enabled": True
        }
    },
    "UserSessionsList": {
        "queryId": "vJ-XatpmQSG8bDch8-t9Jw",
        "variables": {},
        "features": {}
    },
    "UserSuperFollowTweets": {
        "queryId": "80-X1jA2-5dZX4mHC-sivQ",
        "variables": {},
        "features": {
            "responsive_web_twitter_blue_verified_badge_is_enabled": True,
            "responsive_web_graphql_exclude_directive_enabled": True,
            "verified_phone_label_enabled": True,
            "responsive_web_graphql_timeline_navigation_enabled": True,
            "responsive_web_graphql_skip_user_profile_image_extensions_enabled": True,
            "tweetypie_unmention_optimization_enabled": True,
            "vibe_api_enabled": True,
            "responsive_web_edit_tweet_api_enabled": True,
            "graphql_is_translatable_rweb_tweet_is_translatable_enabled": True,
            "view_counts_everywhere_api_enabled": True,
            "longform_notetweets_consumption_enabled": True,
            "tweet_awards_web_tipping_enabled": True,
            "freedom_of_speech_not_reach_fetch_enabled": True,
            "standardized_nudges_misinfo": True,
            "tweet_with_visibility_results_prefer_gql_limited_actions_policy_enabled": True,
            "interactive_text_enabled": True,
            "responsive_web_text_conversations_enabled": True,
            "longform_notetweets_richtext_consumption_enabled": True,
            "responsive_web_enhance_cards_enabled": True
        }
    },
    "UserTweets": {
        "queryId": "CkON7wJrKLwEVV59ClcmjA",
        "variables": {
            "userId": None,
            "count": 1000,
            "includePromotedContent": True,
            "withDownvotePerspective": False,
            "withQuickPromoteEligibilityTweetFields": True,
            "withReactionsMetadata": False,
            "withReactionsPerspective": False,
            "withSuperFollowsTweetFields": True,
            "withSuperFollowsUserFields": True,
            "withV2Timeline": True,
            "withVoice": True
        },
        "features": {
            "responsive_web_twitter_blue_verified_badge_is_enabled": True,
            "responsive_web_graphql_exclude_directive_enabled": True,
            "verified_phone_label_enabled": True,
            "responsive_web_graphql_timeline_navigation_enabled": True,
            "responsive_web_graphql_skip_user_profile_image_extensions_enabled": True,
            "tweetypie_unmention_optimization_enabled": True,
            "vibe_api_enabled": True,
            "responsive_web_edit_tweet_api_enabled": True,
            "graphql_is_translatable_rweb_tweet_is_translatable_enabled": True,
            "view_counts_everywhere_api_enabled": True,
            "longform_notetweets_consumption_enabled": True,
            "tweet_awards_web_tipping_enabled": True,
            "freedom_of_speech_not_reach_fetch_enabled": True,
            "standardized_nudges_misinfo": True,
            "tweet_with_visibility_results_prefer_gql_limited_actions_policy_enabled": True,
            "interactive_text_enabled": True,
            "responsive_web_text_conversations_enabled": True,
            "longform_notetweets_richtext_consumption_enabled": True,
            "responsive_web_enhance_cards_enabled": True
        }
    },
    "UserTweetsAndReplies": {
        "queryId": "WASDBdxt4mOxtWMwlyg_0Q",
        "variables": {
            "userId": None,
            "count": 1000,
            "includePromotedContent": True,
            "withCommunity": True,
            "withDownvotePerspective": False,
            "withReactionsMetadata": False,
            "withReactionsPerspective": False,
            "withSuperFollowsTweetFields": True,
            "withSuperFollowsUserFields": True,
            "withV2Timeline": True,
            "withVoice": True
        },
        "features": {
            "responsive_web_twitter_blue_verified_badge_is_enabled": True,
            "responsive_web_graphql_exclude_directive_enabled": True,
            "verified_phone_label_enabled": True,
            "responsive_web_graphql_timeline_navigation_enabled": True,
            "responsive_web_graphql_skip_user_profile_image_extensions_enabled": True,
            "tweetypie_unmention_optimization_enabled": True,
            "vibe_api_enabled": True,
            "responsive_web_edit_tweet_api_enabled": True,
            "graphql_is_translatable_rweb_tweet_is_translatable_enabled": True,
            "view_counts_everywhere_api_enabled": True,
            "longform_notetweets_consumption_enabled": True,
            "tweet_awards_web_tipping_enabled": True,
            "freedom_of_speech_not_reach_fetch_enabled": True,
            "standardized_nudges_misinfo": True,
            "tweet_with_visibility_results_prefer_gql_limited_actions_policy_enabled": True,
            "interactive_text_enabled": True,
            "responsive_web_text_conversations_enabled": True,
            "longform_notetweets_richtext_consumption_enabled": True,
            "responsive_web_enhance_cards_enabled": True
        }
    },
    "UsersByRestIds": {
        "queryId": "zaTqxMKJ1kzpOxhVbYr1YQ",
        "variables": {
            "userIds": [],
            "withSafetyModeUserFields": True,
            "withSuperFollowsUserFields": True
        },
        "features": {
            "responsive_web_twitter_blue_verified_badge_is_enabled": True,
            "responsive_web_graphql_exclude_directive_enabled": True,
            "verified_phone_label_enabled": True,
            "responsive_web_graphql_skip_user_profile_image_extensions_enabled": True,
            "responsive_web_graphql_timeline_navigation_enabled": True
        }
    },
    "ViewerEmailSettings": {
        "queryId": "JpjlNgn4sLGvS6tgpTzYBg",
        "variables": {},
        "features": {}
    },
    "Viewer": {
        "queryId": "QXO9SjUJXid3NNEovZXydw",
        "variables": {
            "withCommunitiesMemberships": True,
            "withCommunitiesCreation": True,
            "withSuperFollowsUserFields": True
        },
        "features": {
            "responsive_web_twitter_blue_verified_badge_is_enabled": True,
            "responsive_web_graphql_exclude_directive_enabled": True,
            "verified_phone_label_enabled": True,
            "responsive_web_graphql_skip_user_profile_image_extensions_enabled": True,
            "responsive_web_graphql_timeline_navigation_enabled": True
        }
    },
    "ViewerTeams": {
        "queryId": "jqQV7d1CMJ4El2nGSit6aA",
        "variables": {},
        "features": {
            "responsive_web_twitter_blue_verified_badge_is_enabled": True,
            "responsive_web_graphql_exclude_directive_enabled": True,
            "verified_phone_label_enabled": True,
            "responsive_web_graphql_skip_user_profile_image_extensions_enabled": True,
            "responsive_web_graphql_timeline_navigation_enabled": True
        }
    },
    # not included in operations discovery through `update_operations.py`
    "useSendMessageMutation": {
        "queryId": "MaxK2PKX1F9Z-9SwqwavTw",
        "variables": {
            "message": {
                "card": None,
                "media": None,
                "text": None,
                "tweet": None
            },
            "requestId": None,
            "target": None,
        },
    }
}
